/************* Creating a stored procedure to easly remove old table constraints ***************/
IF  EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[sp_ClearConstraints]') AND type in (N'P', N'PC'))
DROP PROCEDURE [dbo].[sp_ClearConstraints]
GO

CREATE PROCEDURE [dbo].[sp_ClearConstraints]
    @TableName varchar(50)
AS
BEGIN
    /* Clear foreign keys */
	DECLARE @schema nvarchar(128), @tbl nvarchar(128), @constraint nvarchar(128)
	DECLARE @sql nvarchar(255)
	DECLARE cur cursor fast_forward for
	SELECT distinct cu.constraint_schema, cu.table_name, cu.constraint_name
	from information_schema.table_constraints tc
	join information_schema.referential_constraints rc on rc.unique_constraint_name = tc.constraint_name
	join information_schema.constraint_column_usage cu on cu.constraint_name = rc.constraint_name
	where tc.constraint_catalog = DB_NAME() and tc.table_name = @TableName
	open cur
	fetch next from cur into @schema, @tbl, @constraint
	while @@fetch_status <> -1
	begin
	 select @sql = 'ALTER TABLE [' + @schema + '].[' + @tbl + '] DROP CONSTRAINT [' + @constraint + ']'
	 exec sp_executesql @sql
	 fetch next from cur into @schema, @tbl, @constraint
	end
	close cur
	deallocate cur 

	/* Clear default values */
	DECLARE cur2 cursor fast_forward for
	SELECT [name] 
	FROM [sys].[default_constraints]
	WHERE [parent_object_id] = object_id(@TableName)

    open cur2
    fetch next from cur2 into @constraint
	while @@fetch_status <> -1
	begin
	 select @sql = 'ALTER TABLE ' + @TableName + ' DROP CONSTRAINT [' + @constraint + ']'
	 exec sp_executesql @sql
	 fetch next from cur2 into @constraint
	end
	close cur2
	deallocate cur2
END
GO

/************** Renaming old tables **************/
exec sp_rename 'Items', 'ItemsOld' 
exec sp_ClearConstraints 'ItemsOld'
GO

exec sp_rename 'VersionedFields', 'VersionedFieldsOld' 
exec sp_ClearConstraints 'VersionedFieldsOld'
GO

exec sp_rename 'UnversionedFields', 'UnversionedFieldsOld' 
exec sp_ClearConstraints 'UnversionedFieldsOld'
GO

exec sp_rename 'SharedFields', 'SharedFieldsOld' 
exec sp_ClearConstraints 'SharedFieldsOld'
GO

exec sp_rename 'IDTable', 'IDTableOld'
exec sp_ClearConstraints 'IDTableOld'
GO

IF  EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[Properties]') AND type in (N'U'))
BEGIN
 exec sp_rename 'Properties', 'PropertiesOld'
 exec sp_ClearConstraints 'PropertiesOld'
END
GO

IF  EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[History]') AND type in (N'U'))
BEGIN
 exec sp_rename 'History', 'HistoryOld'
 exec sp_ClearConstraints 'HistoryOld'
END
GO

IF  EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[WorkflowHistory]') AND type in (N'U'))
BEGIN
 exec sp_rename 'WorkflowHistory', 'WorkflowHistoryOld'
 exec sp_ClearConstraints 'WorkflowHistoryOld'
END
GO

IF  EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[Shadows]') AND type in (N'U'))
BEGIN
 exec sp_rename 'Shadows', 'ShadowsOld'
 exec sp_ClearConstraints 'ShadowsOld'
END
GO

/* Dropping old tables */
IF  EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[ClientData]') AND type in (N'U'))
DROP TABLE [dbo].[ClientData]
GO
IF  EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[Links]') AND type in (N'U'))
DROP TABLE [dbo].[Links]
GO
IF  EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[PublishQueue]') AND type in (N'U'))
DROP TABLE [dbo].[PublishQueue]
GO
IF  EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[Tasks]') AND type in (N'U'))
DROP TABLE [dbo].[Tasks]
GO

/****** Object:  Table [dbo].[AccessControl]    Script Date: 08/28/2008 15:15:28 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
SET ANSI_PADDING ON
GO
CREATE TABLE [dbo].[AccessControl](
	[Id] [uniqueidentifier] NOT NULL,
	[EntityId] [nvarchar](255) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
	[TypeName] [varchar](255) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
	[AccessRules] [nvarchar](max) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
 CONSTRAINT [PK_AccessControl] PRIMARY KEY CLUSTERED 
(
	[Id] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]

GO
/****** Object:  Table [dbo].[Archive]    Script Date: 04/22/2008 10:09:08 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Archive](
	[ArchivalId] [uniqueidentifier] NOT NULL,
	[ItemId] [uniqueidentifier] NOT NULL,
	[ParentId] [uniqueidentifier] NOT NULL,
	[Name] [nvarchar](256) NOT NULL,
	[OriginalLocation] [nvarchar](max) NOT NULL,
	[ArchiveDate] [datetime] NOT NULL,
	[ArchivedBy] [nvarchar](50) NOT NULL,
	[ArchiveName] [nvarchar](50) NOT NULL,
 CONSTRAINT [PK_Archive] PRIMARY KEY CLUSTERED 
(
	[ArchivalId] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO


/****** Object:  Table [dbo].[ArchivedFields]    Script Date: 04/22/2008 10:09:08 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ArchivedFields](
	[RowId] [uniqueidentifier] NOT NULL,
	[ArchivalId] [uniqueidentifier] NOT NULL,
	[SharingType] [nvarchar](50) NOT NULL,
	[ItemId] [uniqueidentifier] NOT NULL,
	[Language] [nvarchar](50) NOT NULL,
	[Version] [int] NOT NULL,
	[FieldId] [uniqueidentifier] NOT NULL,
	[Value] [nvarchar](max) NOT NULL,
	[Created] [datetime] NOT NULL,
	[Updated] [datetime] NOT NULL
) ON [PRIMARY]

GO
/****** Object:  Table [dbo].[ArchivedItems]    Script Date: 04/22/2008 10:09:08 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ArchivedItems](
	[RowId] [uniqueidentifier] NOT NULL,
	[ArchivalId] [uniqueidentifier] NOT NULL,
	[ItemId] [uniqueidentifier] NOT NULL,
	[Name] [nvarchar](256) NOT NULL,
	[TemplateID] [uniqueidentifier] NOT NULL,
	[MasterID] [uniqueidentifier] NOT NULL,
	[ParentID] [uniqueidentifier] NOT NULL,
	[Created] [datetime] NOT NULL,
	[Updated] [datetime] NOT NULL
) ON [PRIMARY]

GO
/****** Object:  Table [dbo].[Blobs]    Script Date: 04/22/2008 10:09:08 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Blobs](
	[Id] [uniqueidentifier] NOT NULL CONSTRAINT [DF_Blobs_Id]  DEFAULT (newid()),
	[BlobId] [uniqueidentifier] NOT NULL,
	[Index] [int] NOT NULL,
	[Data] [image] NOT NULL,
	[Created] [datetime] NOT NULL
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

GO
/****** Object:  Table [dbo].[ClientData]    Script Date: 04/22/2008 10:09:08 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ClientData](
	[ID] [uniqueidentifier] NOT NULL CONSTRAINT [DF_ClientData_ID]  DEFAULT (newid()),
	[SessionKey] [nvarchar](50) NOT NULL,
	[Data] [ntext] NOT NULL,
	[Accessed] [datetime] NOT NULL
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

GO
/****** Object:  Table [dbo].[Descendants]    Script Date: 04/22/2008 10:09:08 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Descendants](
	[ID] [uniqueidentifier] NULL,
	[Ancestor] [uniqueidentifier] NOT NULL,
	[Descendant] [uniqueidentifier] NOT NULL,
 CONSTRAINT [Descendants_PK] PRIMARY KEY CLUSTERED 
(
	[Ancestor] ASC,
	[Descendant] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]

GO
/****** Object:  Table [dbo].[History]    Script Date: 04/22/2008 10:09:08 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
SET ANSI_PADDING ON
GO
CREATE TABLE [dbo].[History](
	[Id] [uniqueidentifier] NOT NULL CONSTRAINT [DF_History_Id]  DEFAULT (newid()),
	[Category] [varchar](50) NOT NULL,
	[Action] [varchar](50) NOT NULL,
	[ItemId] [uniqueidentifier] NOT NULL,
	[ItemLanguage] [varchar](50) NOT NULL,
	[ItemVersion] [int] NOT NULL,
	[ItemPath] [nvarchar](max) NOT NULL CONSTRAINT [DF_History_ItemPath]  DEFAULT (''),
	[UserName] [nvarchar](250) NOT NULL,
	[TaskStack] [varchar](max) NOT NULL CONSTRAINT [DF_History_TaskStack]  DEFAULT (''),
	[AdditionalInfo] [nvarchar](max) NOT NULL CONSTRAINT [DF_History_AdditionalInfo]  DEFAULT (''),
	[Created] [datetime] NOT NULL
) ON [PRIMARY]

GO
SET ANSI_PADDING OFF
GO
/****** Object:  Table [dbo].[IDTable]    Script Date: 04/22/2008 10:09:08 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
SET ANSI_PADDING ON
GO
CREATE TABLE [dbo].[IDTable](
	[ID] [uniqueidentifier] NOT NULL CONSTRAINT [DF_IDTable_ID]  DEFAULT (newid()),
	[Prefix] [varchar](255) NOT NULL,
	[Key] [varchar](255) NOT NULL,
	[ParentID] [uniqueidentifier] NOT NULL,
	[CustomData] [varchar](255) NOT NULL
) ON [PRIMARY]

GO
SET ANSI_PADDING OFF
GO
/****** Object:  Table [dbo].[Items]    Script Date: 04/22/2008 10:09:08 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Items](
	[ID] [uniqueidentifier] NOT NULL,
	[Name] [nvarchar](256) NOT NULL,
	[TemplateID] [uniqueidentifier] NOT NULL,
	[MasterID] [uniqueidentifier] NOT NULL,
	[ParentID] [uniqueidentifier] NOT NULL,
	[Created] [datetime] NOT NULL,
	[Updated] [datetime] NOT NULL
) ON [PRIMARY]

GO
/****** Object:  Table [dbo].[Links]    Script Date: 04/22/2008 10:09:08 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Links](
	[ID] [uniqueidentifier] NOT NULL CONSTRAINT [DF_Links_ID]  DEFAULT (newid()),
	[SourceDatabase] [nvarchar](50) NOT NULL,
	[SourceItemID] [uniqueidentifier] NOT NULL,
	[SourceLanguage] [nvarchar](50) NOT NULL CONSTRAINT [DF_Links_SourceLanguage]  DEFAULT (''),
	[SourceVersion] [int] NOT NULL CONSTRAINT [DF_Links_SourceVersion]  DEFAULT ((0)),
	[SourceFieldID] [uniqueidentifier] NOT NULL,
	[TargetDatabase] [nvarchar](50) NOT NULL,
	[TargetItemID] [uniqueidentifier] NOT NULL,
	[TargetLanguage] [nvarchar](50) NOT NULL CONSTRAINT [DF_Links_TargetLanguage]  DEFAULT (''),
	[TargetPath] [ntext] NOT NULL
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

GO
/****** Object:  Table [dbo].[PublishQueue]    Script Date: 04/22/2008 10:09:08 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[PublishQueue](
	[ID] [uniqueidentifier] NOT NULL CONSTRAINT [DF_PublishQueue_ID]  DEFAULT (newid()),
	[ItemID] [uniqueidentifier] NOT NULL,
	[Language] [nvarchar](50) NOT NULL CONSTRAINT [DF_PublishQueue_Language]  DEFAULT ('en'),
	[Version] [int] NOT NULL CONSTRAINT [DF_PublishQueue_Version]  DEFAULT (1),
	[Action] [nvarchar](50) NOT NULL CONSTRAINT [DF_PublishQueue_Action]  DEFAULT (''),
	[Date] [datetime] NOT NULL,
	[Index] [int] IDENTITY(1,1) NOT NULL
) ON [PRIMARY]

GO
/****** Object:  Table [dbo].[Shadows]    Script Date: 04/22/2008 10:09:08 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Shadows](
	[ID] [uniqueidentifier] NOT NULL CONSTRAINT [DF_Shadows_ID]  DEFAULT (newid()),
	[ProxyID] [uniqueidentifier] NOT NULL,
	[TargetID] [uniqueidentifier] NOT NULL,
	[ShadowID] [uniqueidentifier] NOT NULL
) ON [PRIMARY]

GO
/****** Object:  Table [dbo].[SharedFields]    Script Date: 04/22/2008 10:09:08 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[SharedFields](
	[Id] [uniqueidentifier] NOT NULL CONSTRAINT [DF_SharedFields_Id]  DEFAULT (newid()),
	[ItemId] [uniqueidentifier] NOT NULL,
	[FieldId] [uniqueidentifier] NOT NULL,
	[Value] [nvarchar](max) NOT NULL,
	[Created] [datetime] NOT NULL,
	[Updated] [datetime] NOT NULL
) ON [PRIMARY]

GO
/****** Object:  Table [dbo].[Tasks]    Script Date: 04/22/2008 10:09:08 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Tasks](
	[ID] [uniqueidentifier] NOT NULL,
	[NextRun] [datetime] NOT NULL,
	[taskType] [nvarchar](500) NOT NULL,
	[Parameters] [ntext] NOT NULL,
	[Recurrence] [nvarchar](200) NOT NULL,
	[ItemID] [uniqueidentifier] NOT NULL,
	[Database] [nvarchar](50) NOT NULL,
	[Pending] [int] NOT NULL,
	[Disabled] [int] NOT NULL
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

GO
/****** Object:  Table [dbo].[UnversionedFields]    Script Date: 04/22/2008 10:09:08 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[UnversionedFields](
	[Id] [uniqueidentifier] NOT NULL CONSTRAINT [DF_UnversionedFields_Id]  DEFAULT (newid()),
	[ItemId] [uniqueidentifier] NOT NULL,
	[Language] [nvarchar](50) NOT NULL,
	[FieldId] [uniqueidentifier] NOT NULL,
	[Value] [nvarchar](max) NOT NULL,
	[Created] [datetime] NOT NULL,
	[Updated] [datetime] NOT NULL
) ON [PRIMARY]

GO
/****** Object:  Table [dbo].[VersionedFields]    Script Date: 04/22/2008 10:09:08 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[VersionedFields](
	[Id] [uniqueidentifier] NOT NULL CONSTRAINT [DF_VersionedFields_Id]  DEFAULT (newid()),
	[ItemId] [uniqueidentifier] NOT NULL,
	[Language] [nvarchar](50) NOT NULL,
	[Version] [int] NOT NULL,
	[FieldId] [uniqueidentifier] NOT NULL,
	[Value] [nvarchar](max) NOT NULL,
	[Created] [datetime] NOT NULL,
	[Updated] [datetime] NOT NULL
) ON [PRIMARY]

GO
/****** Object:  Table [dbo].[WorkflowHistory]    Script Date: 04/22/2008 10:09:08 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[WorkflowHistory](
	[ID] [uniqueidentifier] NOT NULL CONSTRAINT [DF_WorkflowHistory_ID]  DEFAULT (newid()),
	[ItemID] [uniqueidentifier] NOT NULL,
	[Language] [nvarchar](20) NOT NULL,
	[Version] [int] NOT NULL,
	[OldState] [nvarchar](200) NOT NULL,
	[NewState] [nvarchar](200) NOT NULL,
	[Text] [nvarchar](2000) NOT NULL,
	[User] [nvarchar](100) NOT NULL,
	[Date] [datetime] NOT NULL,
	[Sequence] [int] IDENTITY(1,1) NOT NULL
) ON [PRIMARY]

/****** Object:  View [dbo].[Fields]    Script Date: 04/22/2008 10:09:48 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE VIEW [dbo].[Fields]
AS
SELECT     Id, ItemId, '' AS Language, FieldId, Value, Created, Updated
FROM         dbo.SharedFields
UNION ALL
SELECT     Id, ItemId, Language, FieldId, Value, Created, Updated
FROM         dbo.UnversionedFields
UNION ALL
SELECT     dbo.VersionedFields.Id, dbo.VersionedFields.ItemId, dbo.VersionedFields.Language, dbo.VersionedFields.FieldId, dbo.VersionedFields.Value, 
                      dbo.VersionedFields.Created, dbo.VersionedFields.Updated
FROM         dbo.VersionedFields INNER JOIN
                          (SELECT     ItemId, Language, MAX(Version) AS Version
                            FROM          dbo.VersionedFields AS VersionedFields_1
                            GROUP BY ItemId, Language) AS b ON dbo.VersionedFields.ItemId = b.ItemId AND dbo.VersionedFields.Language = b.Language AND 
                      dbo.VersionedFields.Version = b.Version
GO

/****** Object:  Table [dbo].[Properties]    Script Date: 07/17/2008 13:21:45 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Properties](
	[ID] [uniqueidentifier] NOT NULL CONSTRAINT [DF_Properties_ID]  DEFAULT (newid()),
	[Key] [nvarchar](256) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
	[Value] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]



/********* Copying data and removing tables *****************/

IF EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[ItemsOld]') AND type in (N'U'))
BEGIN 
 INSERT INTO [dbo].[Items] ([ID], [Name], [TemplateID], [MasterID], [ParentID], [Created], [Updated])
 SELECT [ID], [Name], [TemplateID], [MasterID], [ParentID], [Created], [Updated]
 FROM [dbo].[ItemsOld]
 
 DROP TABLE [dbo].[ItemsOld]
END 
GO

IF EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[PropertiesOld]') AND type in (N'U'))
BEGIN 
 INSERT INTO [dbo].[Properties] ([ID], [Key], [Value])
 SELECT [ID], [Key], [Value]
 FROM [dbo].[PropertiesOld]

 DROP TABLE [dbo].[PropertiesOld]
END
GO

IF  EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[HistoryOld]') AND type in (N'U'))
BEGIN
 INSERT INTO [dbo].[History] ([Id], [Category], [Action], [ItemId], [ItemLanguage], [ItemVersion], [ItemPath], [UserName], [TaskStack], [AdditionalInfo], [Created])
 SELECT [Id], [Category], [Action], [ItemId], [ItemLanguage], [ItemVersion], [ItemPath], [UserName], [TaskStack], [AdditionalInfo], [Created]
 FROM [dbo].[HistoryOld]
 
 DROP TABLE [dbo].[HistoryOld]
END
GO

IF  EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[WorkflowHistoryOld]') AND type in (N'U'))
BEGIN
 INSERT INTO [dbo].[WorkflowHistory] ([ID], [ItemID], [Language], [Version], [OldState], [NewState], [Text], [User], [Date])
 SELECT [ID], [ItemID], [Language], [Version], [OldState], [NewState], [Text], [User], [Date]
 FROM [dbo].[WorkflowHistoryOld]

 DROP TABLE [dbo].[WorkflowHistoryOld]
END
GO

IF  EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[ShadowsOld]') AND type in (N'U'))
BEGIN
 INSERT INTO [dbo].[Shadows] ([ID], [ProxyID], [TargetID], [ShadowID])
 SELECT [ID], [ProxyID], [TargetID], [ShadowID]
 FROM [dbo].[ShadowsOld]
 
 DROP TABLE [dbo].[ShadowsOld]
END
GO

IF EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[IDTableOld]') AND type in (N'U'))
BEGIN 
 INSERT INTO [dbo].[IDTable] ([ID], [Prefix], [Key], [ParentID], [CustomData])
 SELECT [ID], [Prefix], [Key], [ParentID], [CustomData]
 FROM [dbo].[IDTableOld]
 
 DROP TABLE [dbo].[IDTableOld]
END

/*************  Copying, but not deleting fields data **************/
IF EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[UnversionedFieldsOld]') AND type in (N'U'))
BEGIN 
 INSERT INTO [dbo].[UnversionedFields] ([ID], [ItemId], [Language], [FieldId], [Value], [Created], [Updated])
 SELECT [ID], [ItemId], [Language],[FieldId], [Value], [Created], [Updated]
 FROM [dbo].[UnversionedFieldsOld]
END
GO

IF EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[VersionedFieldsOld]') AND type in (N'U'))
BEGIN 
 INSERT INTO [dbo].[VersionedFields] ([ID], [ItemId], [Language], [Version], [FieldId], [Value], [Created], [Updated])
 SELECT [ID], [ItemId], [Language], [Version], [FieldId], [Value], [Created], [Updated]
 FROM [dbo].[VersionedFieldsOld]
END
GO

IF EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[SharedFieldsOld]') AND type in (N'U'))
BEGIN 
 INSERT INTO [dbo].[SharedFields] ([ID], [ItemId], [FieldId], [Value], [Created], [Updated])
 SELECT [ID], [ItemId], [FieldId], [Value], [Created], [Updated]
 FROM [dbo].[SharedFieldsOld]
END
GO

/***************************** Creating indexes *******************************/

/****** Object:  Index [IX_AccessControl]    Script Date: 08/28/2008 15:15:44 ******/
CREATE UNIQUE NONCLUSTERED INDEX [IX_AccessControl] ON [dbo].[AccessControl] 
(
	[EntityId] ASC,
	[TypeName] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]

/****** Object:  Index [ndx_ItemId]    Script Date: 08/28/2008 10:24:15 ******/
CREATE NONCLUSTERED INDEX [ndx_ItemId] ON [dbo].[Archive] 
(
	[ItemId] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]

GO
/****** Object:  Index [ndx_ArchivalId]    Script Date: 08/28/2008 10:25:05 ******/
CREATE NONCLUSTERED INDEX [ndx_ArchivalId] ON [dbo].[ArchivedFields] 
(
	[ArchivalId] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]

GO
/****** Object:  Index [ndx_ArchivalId]    Script Date: 08/28/2008 10:25:28 ******/
CREATE NONCLUSTERED INDEX [ndx_ArchivalId] ON [dbo].[ArchivedItems] 
(
	[ArchivalId] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]

GO

/****** Object:  Index [ndxID]    Script Date: 08/28/2008 10:26:53 ******/
CREATE UNIQUE NONCLUSTERED INDEX [ndxID] ON [dbo].[ClientData] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]

GO
/****** Object:  Index [ndxKey]    Script Date: 08/28/2008 10:27:01 ******/
CREATE NONCLUSTERED INDEX [ndxKey] ON [dbo].[ClientData] 
(
	[SessionKey] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]

GO
/****** Object:  Index [Ancestor]    Script Date: 08/28/2008 10:27:19 ******/
CREATE NONCLUSTERED INDEX [Ancestor] ON [dbo].[Descendants] 
(
	[Ancestor] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]

GO
/****** Object:  Index [Descendant]    Script Date: 08/28/2008 10:27:25 ******/
CREATE NONCLUSTERED INDEX [Descendant] ON [dbo].[Descendants] 
(
	[Descendant] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]

GO
/****** Object:  Index [ndxCreated]    Script Date: 08/28/2008 10:27:42 ******/
CREATE NONCLUSTERED INDEX [ndxCreated] ON [dbo].[History] 
(
	[Created] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]

GO
/****** Object:  Index [ndxID]    Script Date: 08/28/2008 10:27:55 ******/
CREATE UNIQUE NONCLUSTERED INDEX [ndxID] ON [dbo].[IDTable] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]

GO
/****** Object:  Index [ndxPrefixKey]    Script Date: 08/28/2008 10:28:02 ******/
CREATE NONCLUSTERED INDEX [ndxPrefixKey] ON [dbo].[IDTable] 
(
	[Prefix] ASC,
	[Key] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]

GO
/****** Object:  Index [ndxID]    Script Date: 08/28/2008 10:29:22 ******/
CREATE UNIQUE NONCLUSTERED INDEX [ndxID] ON [dbo].[Items] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]

GO
/****** Object:  Index [ndxName]    Script Date: 08/28/2008 10:29:33 ******/
CREATE NONCLUSTERED INDEX [ndxName] ON [dbo].[Items] 
(
	[Name] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]

GO
/****** Object:  Index [ndxParentID]    Script Date: 08/28/2008 10:29:43 ******/
CREATE NONCLUSTERED INDEX [ndxParentID] ON [dbo].[Items] 
(
	[ParentID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]

GO
/****** Object:  Index [ndxTemplateID]    Script Date: 08/28/2008 10:29:50 ******/
CREATE NONCLUSTERED INDEX [ndxTemplateID] ON [dbo].[Items] 
(
	[TemplateID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]

GO
/****** Object:  Index [ndxID]    Script Date: 08/28/2008 10:30:00 ******/
CREATE UNIQUE NONCLUSTERED INDEX [ndxID] ON [dbo].[Links] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]

GO
/****** Object:  Index [ndxSourceItemID]    Script Date: 08/28/2008 10:30:08 ******/
CREATE NONCLUSTERED INDEX [ndxSourceItemID] ON [dbo].[Links] 
(
	[SourceItemID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]

GO
/****** Object:  Index [ndxTargetItemID]    Script Date: 08/28/2008 10:30:15 ******/
CREATE NONCLUSTERED INDEX [ndxTargetItemID] ON [dbo].[Links] 
(
	[TargetItemID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]

GO
/****** Object:  Index [ndxID]    Script Date: 08/28/2008 10:30:26 ******/
CREATE UNIQUE NONCLUSTERED INDEX [ndxID] ON [dbo].[Properties] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]

GO
/****** Object:  Index [ndxKey]    Script Date: 08/28/2008 10:30:32 ******/
CREATE NONCLUSTERED INDEX [ndxKey] ON [dbo].[Properties] 
(
	[Key] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]

GO
/****** Object:  Index [ndxDate]    Script Date: 08/28/2008 10:30:41 ******/
CREATE NONCLUSTERED INDEX [ndxDate] ON [dbo].[PublishQueue] 
(
	[Date] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]

GO
/****** Object:  Index [ndxID]    Script Date: 08/28/2008 10:30:47 ******/
CREATE UNIQUE NONCLUSTERED INDEX [ndxID] ON [dbo].[PublishQueue] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]

GO
/****** Object:  Index [ndxProxyTarget]    Script Date: 08/28/2008 10:30:56 ******/
CREATE NONCLUSTERED INDEX [ndxProxyTarget] ON [dbo].[Shadows] 
(
	[ProxyID] ASC,
	[TargetID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]

GO
/****** Object:  Index [ndxShadowID]    Script Date: 08/28/2008 10:31:04 ******/
CREATE NONCLUSTERED INDEX [ndxShadowID] ON [dbo].[Shadows] 
(
	[ShadowID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]

GO
/****** Object:  Index [ndxTargetID]    Script Date: 08/28/2008 10:31:09 ******/
CREATE NONCLUSTERED INDEX [ndxTargetID] ON [dbo].[Shadows] 
(
	[TargetID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]

GO
/****** Object:  Index [ndxItemID]    Script Date: 08/28/2008 10:31:23 ******/
CREATE CLUSTERED INDEX [ndxItemID] ON [dbo].[SharedFields] 
(
	[ItemId] ASC
)WITH (PAD_INDEX  = ON, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON, FILLFACTOR = 50) ON [PRIMARY]

GO
/****** Object:  Index [ndxUnique]    Script Date: 08/28/2008 10:31:29 ******/
CREATE UNIQUE NONCLUSTERED INDEX [ndxUnique] ON [dbo].[SharedFields] 
(
	[ItemId] ASC,
	[FieldId] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]

GO
/****** Object:  Index [ndxID]    Script Date: 08/28/2008 10:31:39 ******/
CREATE UNIQUE NONCLUSTERED INDEX [ndxID] ON [dbo].[Tasks] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]

GO
/****** Object:  Index [ndxItemID]    Script Date: 08/28/2008 10:31:47 ******/
CREATE CLUSTERED INDEX [ndxItemID] ON [dbo].[UnversionedFields] 
(
	[ItemId] ASC
)WITH (PAD_INDEX  = ON, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON, FILLFACTOR = 50) ON [PRIMARY]

GO
/****** Object:  Index [ndxLookup]    Script Date: 08/28/2008 10:31:52 ******/
CREATE NONCLUSTERED INDEX [ndxLookup] ON [dbo].[UnversionedFields] 
(
	[ItemId] ASC,
	[Language] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]

GO
/****** Object:  Index [ndxUnique]    Script Date: 08/28/2008 10:32:01 ******/
CREATE UNIQUE NONCLUSTERED INDEX [ndxUnique] ON [dbo].[UnversionedFields] 
(
	[ItemId] ASC,
	[Language] ASC,
	[FieldId] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]

GO
/****** Object:  Index [ndxItemID]    Script Date: 08/28/2008 10:32:13 ******/
CREATE CLUSTERED INDEX [ndxItemID] ON [dbo].[VersionedFields] 
(
	[ItemId] ASC
)WITH (PAD_INDEX  = ON, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON, FILLFACTOR = 50) ON [PRIMARY]

GO
/****** Object:  Index [ndxLookup]    Script Date: 08/28/2008 10:32:20 ******/
CREATE NONCLUSTERED INDEX [ndxLookup] ON [dbo].[VersionedFields] 
(
	[ItemId] ASC,
	[Language] ASC,
	[Version] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]

GO
/****** Object:  Index [ndxUnique]    Script Date: 08/28/2008 10:32:27 ******/
CREATE UNIQUE NONCLUSTERED INDEX [ndxUnique] ON [dbo].[VersionedFields] 
(
	[ItemId] ASC,
	[Language] ASC,
	[Version] ASC,
	[FieldId] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]

GO
/****** Object:  Index [ndxID]    Script Date: 08/28/2008 10:32:38 ******/
CREATE UNIQUE NONCLUSTERED INDEX [ndxID] ON [dbo].[WorkflowHistory] 
(
	[ID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]

GO
/****** Object:  Index [ndxItemID]    Script Date: 08/28/2008 10:32:44 ******/
CREATE NONCLUSTERED INDEX [ndxItemID] ON [dbo].[WorkflowHistory] 
(
	[ItemID] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO
/****** Object:  StoredProcedure [dbo].[sp_ClearConstraints]    Script Date: 06/21/2010 11:57:52 ******/
DROP PROCEDURE [dbo].[sp_ClearConstraints]
GO