CREATE TABLE PublishQueue
(
   ID CHAR(32) DEFAULT SYS_GUID() NOT NULL,
   ItemID CHAR(32)  NOT NULL,
   Language NVARCHAR2(50) DEFAULT 'en' NOT NULL,
   Version NUMBER(10,0) DEFAULT 1 NOT NULL,
   Action NVARCHAR2(50) DEFAULT ' '  NOT NULL,
   "Date" TIMESTAMP(3)  NOT NULL,
   "Index" NUMBER(10,0) NOT NULL,
   CONSTRAINT DF_PublishQueue_ID UNIQUE(ID)
);
CREATE TABLE WorkflowHistory
(
   ID CHAR(32) DEFAULT SYS_GUID() NOT NULL,
   ItemID CHAR(32)  NOT NULL,
   Language NVARCHAR2(20) NOT NULL,
   Version NUMBER(10,0) NOT NULL,
   OldState NVARCHAR2(200) NULL,  -- check if NOT NULL is necessary
   NewState NVARCHAR2(200) NOT NULL,
   Text NVARCHAR2(2000) NULL,     -- check if NOT NULL is necessary
   "User" NVARCHAR2(100) NOT NULL,
   "Date" TIMESTAMP(3) NOT NULL,
   SEQUENCE NUMBER(10,0) NOT NULL,
   CONSTRAINT DF_WorkflowHistory_ID UNIQUE(ID)
);
CREATE TABLE Tasks
(
   ID CHAR(32)  NOT NULL,
   NextRun TIMESTAMP(3)  NOT NULL,
   taskType NVARCHAR2(500)  NOT NULL,
   Parameters NCLOB NULL,
   RECURRENCE NVARCHAR2(200)  NOT NULL,
   ItemID CHAR(32)  NOT NULL,
   Database NVARCHAR2(50)  NOT NULL,
   Pending NUMBER(10,0)  NOT NULL,
   Disabled NUMBER(10,0)  NOT NULL
);
CREATE TABLE Properties
(
   ID CHAR(32) DEFAULT SYS_GUID() NOT NULL,
   Key NVARCHAR2(256)  NOT NULL,
   Value NCLOB NULL,
   CONSTRAINT DF_Properties_ID UNIQUE(ID)
);
CREATE TABLE Links
(
   ID CHAR(32) DEFAULT SYS_GUID() NOT NULL,
   SOURCEDATABASE NVARCHAR2(50)  NOT NULL,
   SOURCEITEMID CHAR(32)  NOT NULL,
   SOURCEFIELDID CHAR(32)  NOT NULL,
   TARGETDATABASE NVARCHAR2(50)  NOT NULL,
   TARGETITEMID CHAR(32)  NOT NULL,
   TARGETPATH NCLOB NULL,
   CONSTRAINT DF_Links_ID UNIQUE(ID)
);
CREATE TABLE Items
(
   ID CHAR(32)  NOT NULL,
   Name NVARCHAR2(256)  NOT NULL,
   TemplateID CHAR(32)  NOT NULL,
   MasterID CHAR(32)  NOT NULL,
   ParentID CHAR(32)  NOT NULL,
   Created TIMESTAMP(3) NOT NULL,
   Updated TIMESTAMP(3) NOT NULL,
   CONSTRAINT itemsid_ukey UNIQUE(ID)
);
CREATE TABLE ClientData
(
   SESSIONKEY NVARCHAR2(50) NOT NULL,
   Data NCLOB  NOT NULL,
   ACCESSED TIMESTAMP(3)  NOT NULL,
   ID CHAR(32) DEFAULT SYS_GUID() NOT NULL,
   CONSTRAINT DF_ClientData_ID UNIQUE(ID)
);
CREATE TABLE IDTable
(
   ID CHAR(32) DEFAULT SYS_GUID() NOT NULL,
   Prefix VARCHAR2(255)  NOT NULL,
   Key VARCHAR2(255)  NOT NULL,
   ParentID CHAR(32) NOT NULL,
   CustomData VARCHAR2(255) NOT NULL,
   CONSTRAINT DF_IDTable_ID UNIQUE(ID)
);
CREATE TABLE History
(
   Id CHAR(32) DEFAULT SYS_GUID() NOT NULL,
   Category VARCHAR2(50) NOT NULL,
   Action VARCHAR2(50) NOT NULL,
   ItemId CHAR(32) NOT NULL,
   ItemLanguage VARCHAR2(50) NULL,
   ItemVersion NUMBER(10,0) NOT NULL,
   ItemPath NCLOB NULL,
   UserName VARCHAR2(250) NULL,
   TaskStack NCLOB NULL,
   AdditionalInfo NCLOB NULL,
   Created TIMESTAMP(3) NOT NULL,
   CONSTRAINT DF_History_Id UNIQUE(Id)
);
CREATE TABLE Shadows
(
   ID CHAR(32) DEFAULT SYS_GUID() NOT NULL,
   ProxyID CHAR(32) NOT NULL,
   TargetID CHAR(32) NOT NULL,
   ShadowID CHAR(32) NOT NULL
);
CREATE TABLE SharedFields
(
   Id CHAR(32) DEFAULT SYS_GUID() NOT NULL,
   ItemId CHAR(32) NOT NULL,
   FieldId CHAR(32) NOT NULL,
   Value NCLOB NULL,
   nValue NVARCHAR2(2000) NULL,
   Created TIMESTAMP(3) NOT NULL,
   Updated TIMESTAMP(3) NOT NULL,
   Blob NCLOB  NULL
);
CREATE TABLE UnversionedFields
(
   Id CHAR(32) DEFAULT SYS_GUID() NOT NULL,
   ItemId CHAR(32) NOT NULL,
   Language NVARCHAR2(50) NULL,
   FieldId CHAR(32) NOT NULL,
   Value NCLOB NULL,
   nValue NVARCHAR2(2000) NULL,
   Created TIMESTAMP(3) NOT NULL,
   Updated TIMESTAMP(3) NOT NULL,
   Blob NCLOB  NULL
);
CREATE TABLE VersionedFields
(
   Id CHAR(32) DEFAULT SYS_GUID() NOT NULL,
   ItemId CHAR(32) NOT NULL,
   Language NVARCHAR2(50) NULL,
   Version NUMBER(10,0) NOT NULL,
   FieldId CHAR(32) NOT NULL,
   Value NCLOB NULL,
   nValue NVARCHAR2(2000) NULL,
   Created TIMESTAMP(3) NOT NULL,
   Updated TIMESTAMP(3) NOT NULL,
   Blob NCLOB  NULL
);

CREATE OR REPLACE  PROCEDURE GETFIELDS (v_itemId IN 
    CHAR,
  v_language IN NVARCHAR2,
  v_version number,
  field_ref OUT SYS_REFCURSOR)
   AS
BEGIN
   open field_ref for SELECT FieldId, nValue 
   FROM SharedFields 
   WHERE ItemId = v_itemId 
   UNION ALL 
   SELECT FieldId, nValue 
   FROM UnversionedFields 
   WHERE ItemId = v_itemId AND Language = v_language 
   UNION ALL 
   SELECT FieldId, nValue 
   FROM VersionedFields 
   WHERE ItemId = v_itemId AND Language = v_language AND Version = v_version;
end;
/

--INDEXES
CREATE  INDEX ndxKey ON ClientData
(SESSIONKEY ASC);

CREATE  INDEX ndxName ON Items
(Name ASC);

CREATE  INDEX ndxParentID ON Items
(ParentID ASC);

CREATE  INDEX ndxSourceItemID ON Links
(SOURCEITEMID ASC);

CREATE  INDEX ndxTargetItemID ON Links
(TARGETITEMID ASC);

CREATE  INDEX ndxKeyProp ON Properties
(Key ASC);

CREATE  INDEX ndxDate ON PublishQueue
("Date" ASC);

CREATE  INDEX ndxItemIDWkfl ON WorkflowHistory
(ItemID ASC);

CREATE  INDEX ndxShFields ON SharedFields
(ItemId);

CREATE  INDEX ndxUnVerFields ON UnversionedFields
(ItemId, Language);

CREATE  INDEX ndxVerFields ON VersionedFields
(ItemId, Language, Version);

create index ndxItemIDUnversioned ON UnversionedFields
(ItemID);

create index ndxItemIDVersioned ON VersionedFields
(ItemID);

--SEQUENCE
CREATE SEQUENCE INDEX_SEQ INCREMENT BY 1 START WITH 
    1 MAXVALUE 1.0E28 MINVALUE 1 NOCYCLE 
    CACHE 20 NOORDER;

--SEQUENCE
CREATE SEQUENCE WORKWFLOW_SEQ INCREMENT BY 1 START WITH 
    1 MAXVALUE 1.0E28 MINVALUE 1 NOCYCLE 
    CACHE 20 NOORDER;

--Triggers
CREATE OR REPLACE TRIGGER PQINDEX BEFORE
INSERT ON PUBLISHQUEUE FOR EACH ROW 
begin
    if :new."Index" is null then
        select INDEX_SEQ.nextval into :new."Index" from dual;
    end if;
end;
/
CREATE TRIGGER WORKFLOW_INDEX BEFORE
INSERT ON WORKFLOWHISTORY FOR EACH ROW 
begin
    if :new.SEQUENCE is null then
        select WORKWFLOW_SEQ.nextval into :new.SEQUENCE from dual;
    end if;
end; 
/

exit

