-- creating necessary procedures

create or replace procedure ChangeColumnType 
(tableName in varchar2, 
 columnName in varchar2,
 defaultValue in varchar2,
 notNull in varchar2) 
as
begin
   execute immediate 'ALTER TABLE ' || tableName || ' ADD charid CHAR(32)';
   execute immediate 'UPDATE ' || tableName || ' SET charid = ' || columnName;
   execute immediate 'ALTER TABLE ' || tableName || ' MODIFY (charid ' || defaultValue || notNull || ' )';
   execute immediate 'ALTER TABLE ' || tableName || ' DROP COLUMN ' || columnName || ' CASCADE CONSTRAINT';
   execute immediate 'ALTER TABLE ' || tableName || ' RENAME COLUMN charid TO ' || columnName;
end;
/

create or replace procedure RecreateConstraint
(tableName in varchar2,
 constraintName in varchar2,
 columnName in varchar2)
as
begin
   execute immediate 'ALTER TABLE ' || tableName || ' ADD CONSTRAINT ' || constraintName || ' UNIQUE(' || columnName || ')';
end;
/

-- upgrading data

exec ChangeColumnType('PublishQueue','ID','DEFAULT SYS_GUID()',' NOT NULL');
exec ChangeColumnType('PublishQueue','ItemID','',' NOT NULL');
exec RecreateConstraint('PublishQueue','DF_PublishQueue_ID','ID');

exec ChangeColumnType('WorkflowHistory','ID','DEFAULT SYS_GUID()',' NOT NULL');
exec ChangeColumnType('WorkflowHistory','ItemID','',' NOT NULL');
exec RecreateConstraint('WorkflowHistory','DF_WorkflowHistory_ID','ID');

exec ChangeColumnType('Tasks','ID','',' NOT NULL');
exec ChangeColumnType('Tasks','ItemID','',' NOT NULL');

exec ChangeColumnType('Properties','ID','DEFAULT SYS_GUID()',' NOT NULL');
exec RecreateConstraint('Properties','DF_Properties_ID','ID');

exec ChangeColumnType('Links','ID','DEFAULT SYS_GUID()',' NOT NULL');
exec ChangeColumnType('Links','SOURCEITEMID','',' NOT NULL');
exec ChangeColumnType('Links','SOURCEFIELDID','',' NOT NULL');
exec ChangeColumnType('Links','TARGETITEMID','',' NOT NULL');
exec RecreateConstraint('Links','DF_Links_ID','ID');

exec ChangeColumnType('Items','ID','',' NOT NULL');
exec ChangeColumnType('Items','TemplateID','',' NOT NULL');
exec ChangeColumnType('Items','MasterID','',' NOT NULL');
exec ChangeColumnType('Items','ParentID','',' NOT NULL');
exec RecreateConstraint('Items','itemsid_ukey','ID');

exec ChangeColumnType('ClientData','ID','DEFAULT SYS_GUID()',' NOT NULL');
exec RecreateConstraint('ClientData','DF_ClientData_ID','ID');

exec ChangeColumnType('IDTable','ID','DEFAULT SYS_GUID()',' NOT NULL');
exec ChangeColumnType('IDTable','ParentID','',' NOT NULL');
exec RecreateConstraint('IDTable','DF_IDTable_ID','ID');

exec ChangeColumnType('History','ID','DEFAULT SYS_GUID()',' NOT NULL');
exec ChangeColumnType('History','ItemId','',' NOT NULL');
exec RecreateConstraint('History','DF_History_Id','ID');

exec ChangeColumnType('Shadows','ID','DEFAULT SYS_GUID()',' NOT NULL');
exec ChangeColumnType('Shadows','ProxyID','',' NOT NULL');
exec ChangeColumnType('Shadows','TargetID','',' NOT NULL');
exec ChangeColumnType('Shadows','ShadowID','',' NOT NULL');

exec ChangeColumnType('SharedFields','ID','DEFAULT SYS_GUID()',' NOT NULL');
exec ChangeColumnType('SharedFields','ItemId','',' NOT NULL');
exec ChangeColumnType('SharedFields','FieldId','',' NOT NULL');

exec ChangeColumnType('UnversionedFields','ID','DEFAULT SYS_GUID()',' NOT NULL');
exec ChangeColumnType('UnversionedFields','ItemId','',' NOT NULL');
exec ChangeColumnType('UnversionedFields','FieldId','',' NOT NULL');

exec ChangeColumnType('VersionedFields','ID','DEFAULT SYS_GUID()',' NOT NULL');
exec ChangeColumnType('VersionedFields','ItemId','',' NOT NULL');
exec ChangeColumnType('VersionedFields','FieldId','',' NOT NULL');

-- recreating indexes

CREATE  INDEX ndxParentID ON Items
(ParentID ASC);

CREATE  INDEX ndxSourceItemID ON Links
(SOURCEITEMID ASC);

CREATE  INDEX ndxTargetItemID ON Links
(TARGETITEMID ASC);

CREATE  INDEX ndxItemIDWkfl ON WorkflowHistory
(ItemID ASC);

CREATE  INDEX ndxShFields ON SharedFields
(ItemId);

CREATE  INDEX ndxUnVerFields ON UnversionedFields
(ItemId, Language);

CREATE  INDEX ndxVerFields ON VersionedFields
(ItemId, Language, Version);

create index ndxItemIDUnversioned ON UnversionedFields
(ItemID);

create index ndxItemIDVersioned ON VersionedFields
(ItemID);


-- dropping temporary procedures

drop procedure ChangeColumnType;
drop procedure RecreateConstraint;

exit;