conn scweb/scweb@SITECORE

-- FUNCTIONS

CREATE OR REPLACE  FUNCTION "GETLATESTVERSION"  ( 
  v_itemID IN RAW, 
  v_language IN NVARCHAR2,
  v_default IN NUMBER)
RETURN NUMBER
   AS
   version  NUMBER(10,0);
BEGIN
   begin
      select  NVL(MAX(Version),v_default) INTO version FROM Versions WHERE ItemID = v_itemID
      AND Language = v_language;
      EXCEPTION
      WHEN NO_DATA_FOUND THEN
         NULL;
   end;
   RETURN version;
END;
/

CREATE OR REPLACE  FUNCTION "GETVALIDVERSION"  
 (v_itemID IN RAW,
  v_language IN NVARCHAR2,
  v_version IN NUMBER)
RETURN NUMBER
   AS
   tmpVer NUMBER(10,0);
   tmpCount NUMBER(10,0);
BEGIN
   tmpVer := v_version;
   if(tmpVer = 0) then
      tmpVer := GetLatestVersion(v_itemID,v_language,1);
   ELSE
      if(tmpVer > 1) then
         begin
            SELECT   COUNT(*) INTO tmpCount FROM Versions WHERE ItemID = v_itemID AND Language = v_language AND Version = tmpVer;
            EXCEPTION
            WHEN NO_DATA_FOUND THEN
               NULL;
         end;
         if  tmpCount = 0 then
            tmpVer := 0;
         END IF;
      END IF;
   END IF;
   RETURN tmpVer;
END;
/


CREATE OR REPLACE  FUNCTION "GETVERSIONID"  
 (v_itemID IN RAW,
  v_language IN NVARCHAR2,
  v_version IN NUMBER)
RETURN RAW
   AS
   tmpVer  RAW(16);
BEGIN
   begin
      select  ID INTO tmpVer FROM Versions WHERE ItemID = v_itemID
      AND Language = v_language
      AND Version = v_version;
      EXCEPTION
      WHEN NO_DATA_FOUND THEN
         NULL;
   end;
   RETURN tmpVer;
END;

/


-- STORED PROCEDURES


CREATE OR REPLACE  PROCEDURE "ADDTOPUBLISHQUEUE"   
    (v_itemID IN RAW,
  v_language IN NVARCHAR2,
  v_version IN NUMBER,
  v_date IN TIMESTAMP,
  v_action  IN NVARCHAR2)
   AS
   v_res NUMBER(10,0);
BEGIN
   begin
      SELECT COUNT(*) INTO v_res from PublishQueue where ItemID = v_itemID AND "Date" = v_date;
      EXCEPTION
      WHEN NO_DATA_FOUND THEN
         NULL;
   end;
   if  v_res = 0 then
      INSERT INTO PublishQueue(ItemID,Language,Version,"Date",
    Action,"Index")
      VALUES(v_itemID,v_language,v_version,v_date,v_action,index_seq.nextval);
   END IF;
   RETURN;
END;
/

CREATE OR REPLACE  PROCEDURE "ADDVERSION"    
    (  
    ver_ref OUT SYS_REFCURSOR, 
    v_itemID IN RAW,
  v_language IN NVARCHAR2,
  v_baseVersion IN NUMBER,
  v_versionName IN NVARCHAR2,
  v_now IN TIMESTAMP,
  v_version IN NUMBER DEFAULT 0
  )
AS
   v_versionID  RAW(16);
   v_baseVersionID  RAW(16);
   v_tmpVer NUMBER;

BEGIN

   v_tmpVer := v_version;

   if(v_version = 0) then
      v_tmpVer := GetLatestVersion(v_itemID, v_language, 1) + 1;
   END IF;

   v_versionID := SYS_GUID();

   INSERT INTO Versions(ID, ItemID,Language,Version,Name,Created,Updated)
   VALUES(v_versionID, v_itemID, v_language, v_tmpVer, v_versionName, v_now, v_now);

   open ver_ref for SELECT v_tmpVer  from dual;

   if(v_baseVersion > 0) then
      begin
         select ID INTO v_baseVersionID FROM Versions WHERE ItemID = v_itemID
         AND Language = v_language
         AND Version = v_baseVersion;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            NULL;
      end;

      if(not v_baseVersionID is null) then
         INSERT INTO Fields(VersionID,FieldID,Value,Created,Updated)
         SELECT v_versionID,
                FieldID,
                Value,
                v_now,
                v_now
         FROM   Fields
         WHERE  VersionID = v_baseVersionID;
      END IF;
   END IF;
END;
/

CREATE OR REPLACE  PROCEDURE "CLEANUPPUBLISHQUEUE" 
    (v_to IN TIMESTAMP)
   AS
BEGIN
   DELETE
   FROM PublishQueue
   WHERE "Date" <= v_to;
   RETURN;
END;
/

CREATE OR REPLACE  PROCEDURE "CLIENTDATA_LOAD"   
    (v_sessionKey IN NVARCHAR2,
  v_now IN TIMESTAMP,
  data_ref OUT SYS_REFCURSOR)
   AS
BEGIN
   open data_ref for SELECT Data
   FROM ClientData
   WHERE SESSIONKEY = v_sessionKey;
   UPDATE ClientData
   SET Accessed = v_now
   WHERE SessionKey = v_sessionKey;
   RETURN;
END;

/


CREATE OR REPLACE  PROCEDURE "CLIENTDATA_REMOVE"   
    (v_sessionKey IN NVARCHAR2)
   AS
BEGIN
   DELETE
   FROM ClientData
   WHERE SessionKey = v_sessionKey;
   RETURN;
END;

/


CREATE OR REPLACE  PROCEDURE "CLIENTDATA_STORE"   
    (v_sessionKey IN NVARCHAR2,
  v_data IN NCLOB,
  v_now IN TIMESTAMP)
   AS
BEGIN
   UPDATE ClientData
   SET Data = v_data,Accessed = v_now
   WHERE SessionKey = v_sessionKey;
   if(SQL%ROWCOUNT = 0) then
      INSERT INTO ClientData(SessionKey,Data,Accessed)
      VALUES(v_sessionKey,v_data,v_now);
   END IF;
   RETURN;
END;

/

CREATE OR REPLACE  PROCEDURE "COPYITEM"     (v_itemID
    IN RAW,
  v_destinationID IN RAW,
  v_copyName IN NVARCHAR2,
  v_copyID IN RAW,
  v_now IN TIMESTAMP)
   AS
BEGIN
   INSERT INTO Items(ID,Name,TemplateID,MasterID,ParentID,Created,Updated)
   SELECT v_copyID,
         v_copyName,
         TemplateID,
         MasterID,
         v_destinationID,
         v_now,
         v_now
   FROM Items
   WHERE ID = v_itemID;

   INSERT INTO Versions(ItemID,Language,Version,Name,Created,Updated)
   SELECT v_copyID,
         Language,
         Version,
         Name,
         v_now,
         v_now
   FROM Versions
   WHERE ItemID = v_itemID;

   INSERT INTO Fields(VersionID,FieldID,Value,Created,Updated)
   SELECT V2.ID,
         F.FieldID,
         F.Value,
         v_now,
         v_now
   FROM Fields F, Versions V1, Versions V2
   WHERE V1.ItemID = v_itemID
   AND F.VersionID = V1.ID
   AND V2.ItemID = v_copyID
   AND V2.Language = V1.Language
   AND V2.Version = V1.Version;
   RETURN;
END;
/

CREATE OR REPLACE  PROCEDURE "CREATEITEM"   (v_itemID 
    IN RAW,
  v_itemName IN NVARCHAR2,
  v_templateID IN RAW,
  v_masterID IN RAW,
  v_parentID IN RAW,
  v_now IN TIMESTAMP)
   AS
BEGIN
   INSERT INTO Items(ID,Name,TemplateID,MasterID,ParentID,Created,Updated)
   VALUES(v_itemID,v_itemName,v_templateID,v_masterID,v_parentID,v_now,v_now);
   RETURN;
END;
/

CREATE OR REPLACE  PROCEDURE "DELETEITEM"   (v_itemID
    IN RAW)
   AS
BEGIN
   DELETE
   FROM Items
   WHERE ID = v_itemID;
   RETURN;
END;
/

CREATE OR REPLACE  PROCEDURE "FINDITEMS" 
        (v_fieldID IN RAW,
   v_fieldValue IN NVARCHAR2,
   flds_ref OUT SYS_REFCURSOR  )
   AS
BEGIN
   open flds_ref for SELECT V.ItemID, V.Language, V.Version
      FROM Fields F, Versions V
      WHERE FieldID = v_fieldID
      AND Value LIKE v_fieldValue
      AND F.VersionID = V.ID
      ORDER BY V.ItemID,V.Language,V.Version;
   RETURN;
END;
/

CREATE OR REPLACE  PROCEDURE "GETANYVERSION"   
    (v_itemID IN RAW,
  v_language IN NVARCHAR2,ver_ref OUT SYS_REFCURSOR)
   AS
BEGIN
   open ver_ref for SELECT * FROM(SELECT Language, Version FROM Versions WHERE ItemID = v_itemID
   AND(v_language = '*' OR Language = v_language) ORDER BY Version DESC) WHERE ROWNUM <= 1;
END;
/

CREATE OR REPLACE  PROCEDURE "GETCHILDIDS"    
    (v_itemID
    IN RAW,
  children_ref OUT SYS_REFCURSOR)
   AS
BEGIN
   open children_ref for SELECT ID
   FROM Items
   WHERE ParentID = v_itemID;
   RETURN;
END;
/

CREATE OR REPLACE  PROCEDURE "GETITEMDEFINITION"   
    (v_itemID IN RAW,item_ref OUT SYS_REFCURSOR)
   AS
BEGIN
   open item_ref for SELECT Name, TemplateID, MasterID
   FROM Items
   WHERE ID = v_itemID;
   RETURN;
END;
/

CREATE OR REPLACE  PROCEDURE "GETITEMFIELDS"   
    (v_itemID IN RAW,flds_ref OUT SYS_REFCURSOR)
   AS
BEGIN
   open flds_ref for SELECT f.FieldID, f.Value, v.Language, v.Version
   FROM Fields f, Versions v
   WHERE v.ItemID = v_itemID
   AND f.VersionID = v.ID
   ORDER BY f.Updated;
   RETURN;
END;
/

CREATE OR REPLACE  PROCEDURE "GETLATESTFIELD"   
    (v_itemID IN RAW,
  v_language IN NVARCHAR2,
  v_version IN NUMBER,
  v_fieldID IN RAW,
  v_share IN NUMBER,fld_ref OUT SYS_REFCURSOR)
   AS
BEGIN
   open fld_ref for SELECT f.FieldID, f.Value, f.Updated
   FROM Fields f, Versions v
   WHERE v.ItemID = v_itemID
   AND v.Language = v_language
   AND v.Version = v_version
   AND f.VersionID = v.ID
   AND f.ID = (SELECT * FROM (SELECT f.ID FROM Fields f, Versions v WHERE v.ItemID = v_itemID
   AND(v_share = 1 OR v.Language = v_language)
   AND f.VersionID = v.ID
   AND f.FieldID = v_fieldID ORDER BY f.Updated DESC) WHERE ROWNUM <= 1);
END;
/
CREATE OR REPLACE  PROCEDURE "GETNAMEANDPARENT" 
    (v_itemID IN RAW,data_ref OUT SYS_REFCURSOR)
   AS
BEGIN
   open data_ref for SELECT Name, ParentID
   FROM Items
   WHERE ID = v_itemID;
   RETURN;
END;

/


CREATE OR REPLACE  PROCEDURE "GETPARENTID"   (v_itemID
    IN RAW,parent_ref OUT SYS_REFCURSOR)
   AS
BEGIN
   open parent_ref for SELECT ParentID
   FROM Items
   WHERE ID = v_itemID;
   RETURN;
END;

/


CREATE OR REPLACE  PROCEDURE "GETPROPERTY"     (v_name
    IN NVARCHAR2,prop_ref OUT SYS_REFCURSOR)
   AS
BEGIN
   open prop_ref for SELECT Value
   FROM Properties
   WHERE Key = v_name;
   RETURN;
END;

/

CREATE OR REPLACE  PROCEDURE "GETPUBLISHQUEUE" 
    (v_from IN TIMESTAMP,
  v_to IN TIMESTAMP,publishQ_ref OUT SYS_REFCURSOR)
   AS
BEGIN
   open publishQ_ref for SELECT DISTINCT ItemID
   FROM PublishQueue
   WHERE "Date" BETWEEN v_from
    AND v_to;
   RETURN;
END;
/

CREATE OR REPLACE  PROCEDURE "GETTEMPLATEBASEIDS" 
    (v_fieldID IN RAW, ids_ref OUT SYS_REFCURSOR)
   AS
BEGIN
   open ids_ref for SELECT v.ItemID, f.Value
   FROM Fields f, Versions v
   WHERE f.FieldID = v_fieldID
   AND f.VersionID = v.ID;
   RETURN;
END;
/


CREATE OR REPLACE  PROCEDURE "GETTEMPLATEDATA"  
    (v_templateID IN RAW, data_ref OUT SYS_REFCURSOR  )
   AS
BEGIN
   open data_ref for SELECT V.ItemID, F.FieldID, V.Language, F.Value
   FROM Fields F, Versions V, Items I
   WHERE I.TemplateID = v_templateID
   AND V.ItemID = I.ID
   AND F.VersionID = V.ID
   ORDER BY F.Updated;
   RETURN;
END;
/


CREATE OR REPLACE  PROCEDURE "GETTEMPLATEUSERS" 
    (v_templateID IN RAW, Users_ref OUT SYS_REFCURSOR)
   AS
BEGIN
   open Users_ref for SELECT ID, Name, ParentID
   FROM Items
   WHERE TemplateID = v_templateID;
   RETURN;
END;
/


CREATE OR REPLACE  PROCEDURE "GETVERSIONS"   (v_itemID
    IN RAW,ver_ref OUT SYS_REFCURSOR)
   AS
BEGIN
   open ver_ref for SELECT Language, Version
   FROM Versions
   WHERE ItemID = v_itemID
   ORDER BY Language,Version;
   RETURN;
END;

/

CREATE OR REPLACE  PROCEDURE "MOVEITEM"    (v_itemID 
    IN
    RAW,
  v_destinationID IN RAW,
  v_now IN TIMESTAMP)
   AS
BEGIN
   UPDATE Items
   SET ParentID = v_destinationID, Updated = v_now
   WHERE ID = v_itemID;
   RETURN;
END;

/


CREATE OR REPLACE  PROCEDURE "REMOVEFIELD"    
    (v_itemID
    IN RAW,
  v_language IN NVARCHAR2,
  v_version IN NUMBER,
  v_fieldID IN RAW)
   AS
BEGIN
   DELETE FROM Fields
   WHERE FieldID = v_fieldID
   AND VersionID IN(SELECT ID
   FROM Versions
   WHERE ItemID = v_itemID
   AND Language = v_language
   AND Version = v_version);
   RETURN;
END;

/


CREATE OR REPLACE  PROCEDURE "REMOVEPROPERTY" 
    (v_name IN NVARCHAR2,
  v_isPrefix IN NUMBER)
   AS
BEGIN
   if(v_isPrefix = 1) then
      DELETE FROM Properties
      WHERE Key LIKE(v_name || '%');
   ELSE
      DELETE FROM Properties
      WHERE Key = v_name;
   END IF;
   RETURN;
END;

/

CREATE OR REPLACE  PROCEDURE "REMOVEVERSION"   
    (v_itemID IN RAW,
  v_language IN NVARCHAR2,
  v_version IN NUMBER,
  v_now IN TIMESTAMP)
   AS
BEGIN
   DELETE
   FROM Versions
   WHERE ItemID = v_itemID
   AND Language = v_language
   AND Version = v_version;
   RETURN;
END;

/


CREATE OR REPLACE  PROCEDURE "RESOLVENAME" 
    (v_itemName IN NVARCHAR2,name_ref OUT SYS_REFCURSOR)
   AS
BEGIN
   open name_ref for SELECT ID
   FROM Items
   WHERE Name = v_itemName;
   RETURN;
END;

/

CREATE OR REPLACE  PROCEDURE "SETPROPERTY"   (v_name 
    IN
    NVARCHAR2,
  v_value IN NCLOB)
   AS
BEGIN
   UPDATE Properties
   SET Value = v_value
   WHERE Key = v_name;
   if SQL%ROWCOUNT = 0 then
      INSERT INTO Properties(Key,Value)
      VALUES(v_name,v_value);
   END IF;
   RETURN;
END;
/


CREATE OR REPLACE  PROCEDURE "WORKFLOW_ADDHISTORY"    
   (v_itemID IN RAW,
    v_language IN NVARCHAR2,
    v_version IN NUMBER,
    v_oldState IN NVARCHAR2,
    v_newState IN NVARCHAR2,
    v_text IN NVARCHAR2,
    v_user IN NVARCHAR2,
    v_now IN TIMESTAMP)
   AS
BEGIN
   INSERT INTO WorkflowHistory(ItemID,Language,Version,OldState,NewState,Text,"User","Date", sequence)
   VALUES(v_itemID,v_language,v_version,v_oldState,v_newState,v_text,v_user,v_now, index_seq.nextval);
END;

/


CREATE OR REPLACE  PROCEDURE "WORKFLOW_CLEARHISTORY"  
    (v_itemID IN RAW,
  v_language IN NVARCHAR2,
  v_version IN NUMBER)
   AS
BEGIN
   DELETE
   FROM WorkflowHistory
   WHERE ItemID = v_itemID
   AND Language = v_language
   AND Version = v_version;
END;

/


CREATE OR REPLACE  PROCEDURE "WORKFLOW_GETHISTORY"    
    (v_itemID IN RAW,
  v_language IN NVARCHAR2,
  v_version IN NUMBER, hist_ref OUT SYS_REFCURSOR)
   AS
BEGIN
   open hist_ref for SELECT OldState, NewState, Text, "User", "Date"      
   FROM WorkflowHistory
   WHERE ItemID = v_itemID
   AND Language = v_language
   AND Version = v_version
   ORDER BY SEQUENCE;
END;

/


CREATE OR REPLACE  PROCEDURE "WRITEFIELD"   (v_itemID 
    IN RAW,
  v_language IN NVARCHAR2,
  v_version IN NUMBER,
  v_fieldID IN RAW,
  v_now IN TIMESTAMP,
  v_value IN NCLOB)
   AS
   tmpVerID  RAW(16);
   tmpVerNum  NUMBER(10,0);
BEGIN
   tmpVerID := GetVersionID(v_itemID,v_language,v_version);
   tmpVerNum := 0;
   if(tmpVerID is null) then
      tmpVerID := SYS_GUID();
      INSERT INTO Versions(ID,ItemID,Language,Version,Name,Created,Updated)
      VALUES(tmpVerID,v_itemID,v_language,v_version,'',v_now,v_now);
      tmpVerNum := 1;
   END IF;
   if(tmpVerNum = 0) then
      UPDATE Fields
      SET Value = v_value,Updated = v_now
      WHERE VersionID = tmpVerID
      AND FieldID = v_fieldID;
      if SQL%ROWCOUNT = 0 then
         tmpVerNum := 1;
      END IF;
   END IF;
   if(tmpVerNum = 1) then
      INSERT INTO Fields(VersionID,FieldID,Value,Created,Updated)
      VALUES(tmpVerID,v_fieldID,v_value,v_now,v_now);
   END IF;
   RETURN;
END;

/


CREATE OR REPLACE  PROCEDURE "WRITEITEM"    (v_itemID
    IN RAW,
  v_name IN NVARCHAR2,
  v_templateID IN RAW,
  v_masterID IN RAW,
  v_now IN TIMESTAMP)
   AS
BEGIN
   UPDATE Items
   SET    Name = v_name,TemplateID = v_templateID, MasterID = v_masterID, Updated = v_now
   WHERE  ID = v_itemID;
   RETURN;
END;


/
CREATE OR REPLACE  PROCEDURE "TASKS_UPDATE"       (  
    v_nextRun IN TIMESTAMP,
    v_taskType IN NVARCHAR2,
    v_parameters IN NCLOB,
    v_recurrence IN NVARCHAR2,
    v_itemID IN RAW,
    v_taskID IN RAW,
    v_databaseName IN NVARCHAR2,
    v_insertIfNotFound IN NUMBER
  )
   AS
BEGIN
  
 UPDATE Tasks SET 
   NextRun=v_nextRun,
   TaskType=v_taskType, 
   Parameters=v_parameters, 
   Recurrence=v_recurrence,
   ItemID=v_itemID, 
   Database=v_databaseName, 
   Pending=1 
   WHERE ID=v_taskID;
 
 if(v_insertIfNotFound=1 AND SQL%ROWCOUNT = 0) then
    INSERT INTO Tasks(ID, NextRun, TaskType, Parameters, Recurrence, ItemID, Database, Pending, Disabled) 
    VALUES (v_taskID, v_nextRun, v_taskType, v_parameters, v_recurrence , v_itemID, v_databaseName, 1, 0);
 END IF;
 
END;

/


CREATE OR REPLACE  PROCEDURE "TASKS_UPDATEITEMTASK"   
      (  v_nextRun IN TIMESTAMP,
    v_taskType IN NVARCHAR2,
    v_parameters IN NCLOB,
    v_recurrence IN NVARCHAR2,
    v_itemID IN RAW,
    v_taskID IN RAW,
    v_databaseName IN NVARCHAR2,
    v_insertIfNotFound IN NUMBER
  )
   AS
BEGIN
  
 UPDATE Tasks SET 
   NextRun=v_nextRun,
   TaskType=v_taskType, 
   Parameters=v_parameters, 
   Recurrence=v_recurrence,
   ItemID=v_itemID, 
   Database=v_databaseName, 
   Pending=1 
   WHERE ItemID=v_itemID AND Database=v_databaseName AND TaskType=v_taskType;
 
 if(v_insertIfNotFound=1 AND SQL%ROWCOUNT = 0) then
    INSERT INTO Tasks(ID, NextRun, TaskType, Parameters, Recurrence, ItemID, Database, Pending, Disabled) 
    VALUES (v_taskID, v_nextRun, v_taskType, v_parameters, v_recurrence , v_itemID, v_databaseName, 1, 0);
 END IF;
 
END;

/
exit