drop tablespace sitecore;

CREATE TABLESPACE sitecore 
    LOGGING 
    DATAFILE 'D:\ORACLE\ORADATA\SITECORE\SITECORE.ORA' SIZE 50M 
    REUSE EXTENT MANAGEMENT LOCAL
/

drop user scCore cascade;

CREATE USER scCore
IDENTIFIED BY scCore
DEFAULT TABLESPACE sitecore
TEMPORARY TABLESPACE temp
QUOTA UNLIMITED ON sitecore
/

drop user scMaster cascade;

CREATE USER scMaster
IDENTIFIED BY scMaster
DEFAULT TABLESPACE sitecore
TEMPORARY TABLESPACE temp
QUOTA UNLIMITED ON sitecore
/

drop user scArc cascade;

CREATE USER scArc
IDENTIFIED BY scArc
DEFAULT TABLESPACE sitecore
TEMPORARY TABLESPACE temp
QUOTA UNLIMITED ON sitecore
/

drop user scRecBin cascade;

CREATE USER scRecBin
IDENTIFIED BY scRecBin
DEFAULT TABLESPACE sitecore
TEMPORARY TABLESPACE temp
QUOTA UNLIMITED ON sitecore
/

drop user scWeb cascade;

CREATE USER scWeb
IDENTIFIED BY scWeb
DEFAULT TABLESPACE sitecore
TEMPORARY TABLESPACE temp
QUOTA UNLIMITED ON sitecore
/

drop user scExtranet cascade;

CREATE USER scExtranet
IDENTIFIED BY scExtranet
DEFAULT TABLESPACE sitecore
TEMPORARY TABLESPACE temp
QUOTA UNLIMITED ON sitecore
/

drop user scSecurity cascade;

CREATE USER scSecurity
IDENTIFIED BY scSecurity
DEFAULT TABLESPACE sitecore
TEMPORARY TABLESPACE temp
QUOTA UNLIMITED ON sitecore
/

drop role scRole;
CREATE ROLE scRole;

GRANT CREATE session, CREATE table, CREATE view, CREATE procedure, CREATE synonym, CREATE sequence TO scRole;

GRANT scRole to scCore;
GRANT scRole to scMaster;
GRANT scRole to scArc;
GRANT scRole to scRecBin;
GRANT scRole to scWeb;
GRANT scRole to scExtranet;
GRANT scRole to scSecurity;

--- ********************************************
--- Creating schema for scCore
--- ********************************************

conn scCore/scCore@SITECORE

CREATE SCHEMA AUTHORIZATION scCore
CREATE TABLE PublishQueue
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   ItemID RAW(16)  NOT NULL,
   Language NVARCHAR2(50) DEFAULT 'en' NOT NULL,
   Version NUMBER(10,0) DEFAULT 1 NOT NULL,
   Action NVARCHAR2(50) DEFAULT ' '  NOT NULL,
   "Date" TIMESTAMP(3)  NOT NULL,
   "Index" NUMBER(10,0) NOT NULL
)
CREATE TABLE Fields
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   FieldID RAW(16)  NOT NULL,
   Value NCLOB,
   Created TIMESTAMP(3)  NOT NULL,
   Updated TIMESTAMP(3)  NOT NULL,
   VersionID RAW(16)  NOT NULL
)
CREATE TABLE Versions
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   Name NVARCHAR2(250),
   ItemID RAW(16) NOT NULL,
   Language NVARCHAR2(20) NOT NULL,
   Version NUMBER(10,0) NOT NULL,
   Created TIMESTAMP(3) NOT NULL,
   Updated TIMESTAMP(3) DEFAULT SYSTIMESTAMP NOT NULL,
   CONSTRAINT verid_ukey UNIQUE(ID)
)
CREATE TABLE WorkflowHistory
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   ItemID RAW(16)  NOT NULL,
   Language NVARCHAR2(20) NOT NULL,
   Version NUMBER(10,0) NOT NULL,
   OldState NVARCHAR2(200),
   NewState NVARCHAR2(200) NOT NULL,
   Text NVARCHAR2(2000),
   "User" NVARCHAR2(100) NOT NULL,
   "Date" TIMESTAMP(3) NOT NULL,
   SEQUENCE NUMBER(10,0) NOT NULL
)
CREATE TABLE Tasks
(
   ID RAW(16)  NOT NULL,
   NextRun TIMESTAMP(3)  NOT NULL,
   taskType NVARCHAR2(500)  NOT NULL,
   Parameters NCLOB,
   RECURRENCE NVARCHAR2(200)  NOT NULL,
   ItemID RAW(16)  NOT NULL,
   Database NVARCHAR2(50)  NOT NULL,
   Pending NUMBER(10,0)  NOT NULL,
   Disabled NUMBER(10,0)  NOT NULL
)
CREATE TABLE Properties
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   Key NVARCHAR2(256)  NOT NULL,
   Value NCLOB
)
CREATE TABLE Links
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   SOURCEDATABASE NVARCHAR2(50)  NOT NULL,
   SOURCEITEMID RAW(16)  NOT NULL,
   SOURCEFIELDID RAW(16)  NOT NULL,
   TARGETDATABASE NVARCHAR2(50)  NOT NULL,
   TARGETITEMID RAW(16)  NOT NULL,
   TARGETPATH NVARCHAR2(500)
)
CREATE TABLE Items
(
   ID RAW(16)  NOT NULL,
   Name NVARCHAR2(256)  NOT NULL,
   TemplateID RAW(16)  NOT NULL,
   MasterID RAW(16)  NOT NULL,
   ParentID RAW(16)  NOT NULL,
   Created TIMESTAMP(3) NOT NULL,
   Updated TIMESTAMP(3) NOT NULL,
   CONSTRAINT itemsid_ukey UNIQUE(ID)
)
CREATE TABLE ClientData
(
   SESSIONKEY NVARCHAR2(50) NOT NULL,
   Data NCLOB  NOT NULL,
   ACCESSED TIMESTAMP(3)  NOT NULL,
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL
)
CREATE TABLE IDTable
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   Prefix VARCHAR2(255)  NOT NULL,
   Key VARCHAR2(255)  NOT NULL,
   ParentID RAW(16) NOT NULL,
   CustomData VARCHAR2(255) NOT NULL,
   CONSTRAINT PK_IDTable PRIMARY KEY(Prefix,Key)
)
CREATE TABLE Shadows
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   ProxyID RAW(16) NOT NULL,
   TargetID RAW(16) NOT NULL,
   ShadowID RAW(16) NOT NULL
);


--INDEXES
CREATE  INDEX ndxKey ON ClientData
(SESSIONKEY ASC);

CREATE UNIQUE  INDEX ndxIDFld ON Fields
(ID ASC);

CREATE  INDEX ndxVersionID ON Fields
(VersionID ASC);

CREATE  INDEX ndxName ON Items
(Name ASC);

CREATE  INDEX ndxParentID ON Items
(ParentID ASC);

CREATE  INDEX ndxSourceItemID ON Links
(SOURCEITEMID ASC);

CREATE  INDEX ndxTargetItemID ON Links
(TARGETITEMID ASC);

CREATE  INDEX ndxKeyProp ON Properties
(Key ASC);

CREATE  INDEX ndxDate ON PublishQueue
("Date" ASC);

CREATE  INDEX ndxItemID ON Versions
(ItemID ASC);

CREATE  INDEX ndxItemIDWkfl ON WorkflowHistory
(ItemID ASC);

--SEQUENCE
CREATE SEQUENCE INDEX_SEQ INCREMENT BY 1 START WITH 
    21 MAXVALUE 1.0E28 MINVALUE 1 NOCYCLE 
    CACHE 20 NOORDER;

--FOREIGN KEY
ALTER TABLE Fields ADD  CONSTRAINT FK_VERSION FOREIGN KEY(VersionID)
REFERENCES Versions(ID) ON DELETE CASCADE;

ALTER TABLE Versions ADD CONSTRAINT FK_ITEM FOREIGN KEY(ItemID)
REFERENCES Items(ID) ON DELETE CASCADE
/


--- ********************************************
--- Creating schema for scMaster
--- ********************************************

conn scMaster/scMaster@SITECORE

CREATE SCHEMA AUTHORIZATION scMaster
CREATE TABLE PublishQueue
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   ItemID RAW(16)  NOT NULL,
   Language NVARCHAR2(50) DEFAULT 'en' NOT NULL,
   Version NUMBER(10,0) DEFAULT 1 NOT NULL,
   Action NVARCHAR2(50) DEFAULT ' '  NOT NULL,
   "Date" TIMESTAMP(3)  NOT NULL,
   "Index" NUMBER(10,0) NOT NULL
)
CREATE TABLE Fields
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   FieldID RAW(16)  NOT NULL,
   Value NCLOB,
   Created TIMESTAMP(3)  NOT NULL,
   Updated TIMESTAMP(3)  NOT NULL,
   VersionID RAW(16)  NOT NULL
)
CREATE TABLE Versions
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   Name NVARCHAR2(250),
   ItemID RAW(16) NOT NULL,
   Language NVARCHAR2(20) NOT NULL,
   Version NUMBER(10,0) NOT NULL,
   Created TIMESTAMP(3) NOT NULL,
   Updated TIMESTAMP(3) DEFAULT SYSTIMESTAMP NOT NULL,
   CONSTRAINT verid_ukey UNIQUE(ID)
)
CREATE TABLE WorkflowHistory
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   ItemID RAW(16)  NOT NULL,
   Language NVARCHAR2(20) NOT NULL,
   Version NUMBER(10,0) NOT NULL,
   OldState NVARCHAR2(200),
   NewState NVARCHAR2(200) NOT NULL,
   Text NVARCHAR2(2000),
   "User" NVARCHAR2(100) NOT NULL,
   "Date" TIMESTAMP(3) NOT NULL,
   SEQUENCE NUMBER(10,0) NOT NULL
)
CREATE TABLE Tasks
(
   ID RAW(16)  NOT NULL,
   NextRun TIMESTAMP(3)  NOT NULL,
   taskType NVARCHAR2(500)  NOT NULL,
   Parameters NCLOB,
   RECURRENCE NVARCHAR2(200)  NOT NULL,
   ItemID RAW(16)  NOT NULL,
   Database NVARCHAR2(50)  NOT NULL,
   Pending NUMBER(10,0)  NOT NULL,
   Disabled NUMBER(10,0)  NOT NULL
)
CREATE TABLE Properties
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   Key NVARCHAR2(256)  NOT NULL,
   Value NCLOB
)
CREATE TABLE Links
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   SOURCEDATABASE NVARCHAR2(50)  NOT NULL,
   SOURCEITEMID RAW(16)  NOT NULL,
   SOURCEFIELDID RAW(16)  NOT NULL,
   TARGETDATABASE NVARCHAR2(50)  NOT NULL,
   TARGETITEMID RAW(16)  NOT NULL,
   TARGETPATH NVARCHAR2(500)
)
CREATE TABLE Items
(
   ID RAW(16)  NOT NULL,
   Name NVARCHAR2(256)  NOT NULL,
   TemplateID RAW(16)  NOT NULL,
   MasterID RAW(16)  NOT NULL,
   ParentID RAW(16)  NOT NULL,
   Created TIMESTAMP(3) NOT NULL,
   Updated TIMESTAMP(3) NOT NULL,
   CONSTRAINT itemsid_ukey UNIQUE(ID)
)
CREATE TABLE ClientData
(
   SESSIONKEY NVARCHAR2(50) NOT NULL,
   Data NCLOB  NOT NULL,
   ACCESSED TIMESTAMP(3)  NOT NULL,
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL
)
CREATE TABLE IDTable
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   Prefix VARCHAR2(255)  NOT NULL,
   Key VARCHAR2(255)  NOT NULL,
   ParentID RAW(16) NOT NULL,
   CustomData VARCHAR2(255) NOT NULL,
   CONSTRAINT PK_IDTable PRIMARY KEY(Prefix,Key)
)
CREATE TABLE Shadows
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   ProxyID RAW(16) NOT NULL,
   TargetID RAW(16) NOT NULL,
   ShadowID RAW(16) NOT NULL
);


--INDEXES
CREATE  INDEX ndxKey ON ClientData
(SESSIONKEY ASC);

CREATE UNIQUE  INDEX ndxIDFld ON Fields
(ID ASC);

CREATE  INDEX ndxVersionID ON Fields
(VersionID ASC);

CREATE  INDEX ndxName ON Items
(Name ASC);

CREATE  INDEX ndxParentID ON Items
(ParentID ASC);

CREATE  INDEX ndxSourceItemID ON Links
(SOURCEITEMID ASC);

CREATE  INDEX ndxTargetItemID ON Links
(TARGETITEMID ASC);

CREATE  INDEX ndxKeyProp ON Properties
(Key ASC);

CREATE  INDEX ndxDate ON PublishQueue
("Date" ASC);

CREATE  INDEX ndxItemID ON Versions
(ItemID ASC);

CREATE  INDEX ndxItemIDWkfl ON WorkflowHistory
(ItemID ASC);

--SEQUENCE
CREATE SEQUENCE INDEX_SEQ INCREMENT BY 1 START WITH 
    21 MAXVALUE 1.0E28 MINVALUE 1 NOCYCLE 
    CACHE 20 NOORDER;

--FOREIGN KEY
ALTER TABLE Fields ADD  CONSTRAINT FK_VERSION FOREIGN KEY(VersionID)
REFERENCES Versions(ID) ON DELETE CASCADE;

ALTER TABLE Versions ADD CONSTRAINT FK_ITEM FOREIGN KEY(ItemID)
REFERENCES Items(ID) ON DELETE CASCADE
/

--- ********************************************
--- Creating schema for scArc
--- ********************************************

conn scArc/scArc@SITECORE

CREATE SCHEMA AUTHORIZATION scArc
CREATE TABLE PublishQueue
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   ItemID RAW(16)  NOT NULL,
   Language NVARCHAR2(50) DEFAULT 'en' NOT NULL,
   Version NUMBER(10,0) DEFAULT 1 NOT NULL,
   Action NVARCHAR2(50) DEFAULT ' '  NOT NULL,
   "Date" TIMESTAMP(3)  NOT NULL,
   "Index" NUMBER(10,0) NOT NULL
)
CREATE TABLE Fields
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   FieldID RAW(16)  NOT NULL,
   Value NCLOB,
   Created TIMESTAMP(3)  NOT NULL,
   Updated TIMESTAMP(3)  NOT NULL,
   VersionID RAW(16)  NOT NULL
)
CREATE TABLE Versions
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   Name NVARCHAR2(250),
   ItemID RAW(16) NOT NULL,
   Language NVARCHAR2(20) NOT NULL,
   Version NUMBER(10,0) NOT NULL,
   Created TIMESTAMP(3) NOT NULL,
   Updated TIMESTAMP(3) DEFAULT SYSTIMESTAMP NOT NULL,
   CONSTRAINT verid_ukey UNIQUE(ID)
)
CREATE TABLE WorkflowHistory
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   ItemID RAW(16)  NOT NULL,
   Language NVARCHAR2(20) NOT NULL,
   Version NUMBER(10,0) NOT NULL,
   OldState NVARCHAR2(200),
   NewState NVARCHAR2(200) NOT NULL,
   Text NVARCHAR2(2000),
   "User" NVARCHAR2(100) NOT NULL,
   "Date" TIMESTAMP(3) NOT NULL,
   SEQUENCE NUMBER(10,0) NOT NULL
)
CREATE TABLE Tasks
(
   ID RAW(16)  NOT NULL,
   NextRun TIMESTAMP(3)  NOT NULL,
   taskType NVARCHAR2(500)  NOT NULL,
   Parameters NCLOB,
   RECURRENCE NVARCHAR2(200)  NOT NULL,
   ItemID RAW(16)  NOT NULL,
   Database NVARCHAR2(50)  NOT NULL,
   Pending NUMBER(10,0)  NOT NULL,
   Disabled NUMBER(10,0)  NOT NULL
)
CREATE TABLE Properties
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   Key NVARCHAR2(256)  NOT NULL,
   Value NCLOB
)
CREATE TABLE Links
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   SOURCEDATABASE NVARCHAR2(50)  NOT NULL,
   SOURCEITEMID RAW(16)  NOT NULL,
   SOURCEFIELDID RAW(16)  NOT NULL,
   TARGETDATABASE NVARCHAR2(50)  NOT NULL,
   TARGETITEMID RAW(16)  NOT NULL,
   TARGETPATH NVARCHAR2(500)
)
CREATE TABLE Items
(
   ID RAW(16)  NOT NULL,
   Name NVARCHAR2(256)  NOT NULL,
   TemplateID RAW(16)  NOT NULL,
   MasterID RAW(16)  NOT NULL,
   ParentID RAW(16)  NOT NULL,
   Created TIMESTAMP(3) NOT NULL,
   Updated TIMESTAMP(3) NOT NULL,
   CONSTRAINT itemsid_ukey UNIQUE(ID)
)
CREATE TABLE ClientData
(
   SESSIONKEY NVARCHAR2(50) NOT NULL,
   Data NCLOB  NOT NULL,
   ACCESSED TIMESTAMP(3)  NOT NULL,
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL
)
CREATE TABLE IDTable
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   Prefix VARCHAR2(255)  NOT NULL,
   Key VARCHAR2(255)  NOT NULL,
   ParentID RAW(16) NOT NULL,
   CustomData VARCHAR2(255) NOT NULL,
   CONSTRAINT PK_IDTable PRIMARY KEY(Prefix,Key)
)
CREATE TABLE Shadows
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   ProxyID RAW(16) NOT NULL,
   TargetID RAW(16) NOT NULL,
   ShadowID RAW(16) NOT NULL
);


--INDEXES
CREATE  INDEX ndxKey ON ClientData
(SESSIONKEY ASC);

CREATE UNIQUE  INDEX ndxIDFld ON Fields
(ID ASC);

CREATE  INDEX ndxVersionID ON Fields
(VersionID ASC);

CREATE  INDEX ndxName ON Items
(Name ASC);

CREATE  INDEX ndxParentID ON Items
(ParentID ASC);

CREATE  INDEX ndxSourceItemID ON Links
(SOURCEITEMID ASC);

CREATE  INDEX ndxTargetItemID ON Links
(TARGETITEMID ASC);

CREATE  INDEX ndxKeyProp ON Properties
(Key ASC);

CREATE  INDEX ndxDate ON PublishQueue
("Date" ASC);

CREATE  INDEX ndxItemID ON Versions
(ItemID ASC);

CREATE  INDEX ndxItemIDWkfl ON WorkflowHistory
(ItemID ASC);

--SEQUENCE
CREATE SEQUENCE INDEX_SEQ INCREMENT BY 1 START WITH 
    21 MAXVALUE 1.0E28 MINVALUE 1 NOCYCLE 
    CACHE 20 NOORDER;

--FOREIGN KEY
ALTER TABLE Fields ADD  CONSTRAINT FK_VERSION FOREIGN KEY(VersionID)
REFERENCES Versions(ID) ON DELETE CASCADE;

ALTER TABLE Versions ADD CONSTRAINT FK_ITEM FOREIGN KEY(ItemID)
REFERENCES Items(ID) ON DELETE CASCADE
/

--- ********************************************
--- Creating schema for scRecBin
--- ********************************************

conn scRecBin/scRecBin@SITECORE

CREATE SCHEMA AUTHORIZATION scRecBin
CREATE TABLE PublishQueue
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   ItemID RAW(16)  NOT NULL,
   Language NVARCHAR2(50) DEFAULT 'en' NOT NULL,
   Version NUMBER(10,0) DEFAULT 1 NOT NULL,
   Action NVARCHAR2(50) DEFAULT ' '  NOT NULL,
   "Date" TIMESTAMP(3)  NOT NULL,
   "Index" NUMBER(10,0) NOT NULL
)
CREATE TABLE Fields
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   FieldID RAW(16)  NOT NULL,
   Value NCLOB,
   Created TIMESTAMP(3)  NOT NULL,
   Updated TIMESTAMP(3)  NOT NULL,
   VersionID RAW(16)  NOT NULL
)
CREATE TABLE Versions
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   Name NVARCHAR2(250),
   ItemID RAW(16) NOT NULL,
   Language NVARCHAR2(20) NOT NULL,
   Version NUMBER(10,0) NOT NULL,
   Created TIMESTAMP(3) NOT NULL,
   Updated TIMESTAMP(3) DEFAULT SYSTIMESTAMP NOT NULL,
   CONSTRAINT verid_ukey UNIQUE(ID)
)
CREATE TABLE WorkflowHistory
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   ItemID RAW(16)  NOT NULL,
   Language NVARCHAR2(20) NOT NULL,
   Version NUMBER(10,0) NOT NULL,
   OldState NVARCHAR2(200),
   NewState NVARCHAR2(200) NOT NULL,
   Text NVARCHAR2(2000),
   "User" NVARCHAR2(100) NOT NULL,
   "Date" TIMESTAMP(3) NOT NULL,
   SEQUENCE NUMBER(10,0) NOT NULL
)
CREATE TABLE Tasks
(
   ID RAW(16)  NOT NULL,
   NextRun TIMESTAMP(3)  NOT NULL,
   taskType NVARCHAR2(500)  NOT NULL,
   Parameters NCLOB,
   RECURRENCE NVARCHAR2(200)  NOT NULL,
   ItemID RAW(16)  NOT NULL,
   Database NVARCHAR2(50)  NOT NULL,
   Pending NUMBER(10,0)  NOT NULL,
   Disabled NUMBER(10,0)  NOT NULL
)
CREATE TABLE Properties
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   Key NVARCHAR2(256)  NOT NULL,
   Value NCLOB
)
CREATE TABLE Links
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   SOURCEDATABASE NVARCHAR2(50)  NOT NULL,
   SOURCEITEMID RAW(16)  NOT NULL,
   SOURCEFIELDID RAW(16)  NOT NULL,
   TARGETDATABASE NVARCHAR2(50)  NOT NULL,
   TARGETITEMID RAW(16)  NOT NULL,
   TARGETPATH NVARCHAR2(500)
)
CREATE TABLE Items
(
   ID RAW(16)  NOT NULL,
   Name NVARCHAR2(256)  NOT NULL,
   TemplateID RAW(16)  NOT NULL,
   MasterID RAW(16)  NOT NULL,
   ParentID RAW(16)  NOT NULL,
   Created TIMESTAMP(3) NOT NULL,
   Updated TIMESTAMP(3) NOT NULL,
   CONSTRAINT itemsid_ukey UNIQUE(ID)
)
CREATE TABLE ClientData
(
   SESSIONKEY NVARCHAR2(50) NOT NULL,
   Data NCLOB  NOT NULL,
   ACCESSED TIMESTAMP(3)  NOT NULL,
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL
)
CREATE TABLE IDTable
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   Prefix VARCHAR2(255)  NOT NULL,
   Key VARCHAR2(255)  NOT NULL,
   ParentID RAW(16) NOT NULL,
   CustomData VARCHAR2(255) NOT NULL,
   CONSTRAINT PK_IDTable PRIMARY KEY(Prefix,Key)
)
CREATE TABLE Shadows
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   ProxyID RAW(16) NOT NULL,
   TargetID RAW(16) NOT NULL,
   ShadowID RAW(16) NOT NULL
);


--INDEXES
CREATE  INDEX ndxKey ON ClientData
(SESSIONKEY ASC);

CREATE UNIQUE  INDEX ndxIDFld ON Fields
(ID ASC);

CREATE  INDEX ndxVersionID ON Fields
(VersionID ASC);

CREATE  INDEX ndxName ON Items
(Name ASC);

CREATE  INDEX ndxParentID ON Items
(ParentID ASC);

CREATE  INDEX ndxSourceItemID ON Links
(SOURCEITEMID ASC);

CREATE  INDEX ndxTargetItemID ON Links
(TARGETITEMID ASC);

CREATE  INDEX ndxKeyProp ON Properties
(Key ASC);

CREATE  INDEX ndxDate ON PublishQueue
("Date" ASC);

CREATE  INDEX ndxItemID ON Versions
(ItemID ASC);

CREATE  INDEX ndxItemIDWkfl ON WorkflowHistory
(ItemID ASC);

--SEQUENCE
CREATE SEQUENCE INDEX_SEQ INCREMENT BY 1 START WITH 
    21 MAXVALUE 1.0E28 MINVALUE 1 NOCYCLE 
    CACHE 20 NOORDER;

--FOREIGN KEY
ALTER TABLE Fields ADD  CONSTRAINT FK_VERSION FOREIGN KEY(VersionID)
REFERENCES Versions(ID) ON DELETE CASCADE;

ALTER TABLE Versions ADD CONSTRAINT FK_ITEM FOREIGN KEY(ItemID)
REFERENCES Items(ID) ON DELETE CASCADE
/

--- ********************************************
--- Creating schema for scWeb
--- ********************************************

conn scWeb/scWeb@SITECORE

CREATE SCHEMA AUTHORIZATION scWeb
CREATE TABLE PublishQueue
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   ItemID RAW(16)  NOT NULL,
   Language NVARCHAR2(50) DEFAULT 'en' NOT NULL,
   Version NUMBER(10,0) DEFAULT 1 NOT NULL,
   Action NVARCHAR2(50) DEFAULT ' '  NOT NULL,
   "Date" TIMESTAMP(3)  NOT NULL,
   "Index" NUMBER(10,0) NOT NULL
)
CREATE TABLE Fields
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   FieldID RAW(16)  NOT NULL,
   Value NCLOB,
   Created TIMESTAMP(3)  NOT NULL,
   Updated TIMESTAMP(3)  NOT NULL,
   VersionID RAW(16)  NOT NULL
)
CREATE TABLE Versions
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   Name NVARCHAR2(250),
   ItemID RAW(16) NOT NULL,
   Language NVARCHAR2(20) NOT NULL,
   Version NUMBER(10,0) NOT NULL,
   Created TIMESTAMP(3) NOT NULL,
   Updated TIMESTAMP(3) DEFAULT SYSTIMESTAMP NOT NULL,
   CONSTRAINT verid_ukey UNIQUE(ID)
)
CREATE TABLE WorkflowHistory
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   ItemID RAW(16)  NOT NULL,
   Language NVARCHAR2(20) NOT NULL,
   Version NUMBER(10,0) NOT NULL,
   OldState NVARCHAR2(200),
   NewState NVARCHAR2(200) NOT NULL,
   Text NVARCHAR2(2000),
   "User" NVARCHAR2(100) NOT NULL,
   "Date" TIMESTAMP(3) NOT NULL,
   SEQUENCE NUMBER(10,0) NOT NULL
)
CREATE TABLE Tasks
(
   ID RAW(16)  NOT NULL,
   NextRun TIMESTAMP(3)  NOT NULL,
   taskType NVARCHAR2(500)  NOT NULL,
   Parameters NCLOB,
   RECURRENCE NVARCHAR2(200)  NOT NULL,
   ItemID RAW(16)  NOT NULL,
   Database NVARCHAR2(50)  NOT NULL,
   Pending NUMBER(10,0)  NOT NULL,
   Disabled NUMBER(10,0)  NOT NULL
)
CREATE TABLE Properties
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   Key NVARCHAR2(256)  NOT NULL,
   Value NCLOB
)
CREATE TABLE Links
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   SOURCEDATABASE NVARCHAR2(50)  NOT NULL,
   SOURCEITEMID RAW(16)  NOT NULL,
   SOURCEFIELDID RAW(16)  NOT NULL,
   TARGETDATABASE NVARCHAR2(50)  NOT NULL,
   TARGETITEMID RAW(16)  NOT NULL,
   TARGETPATH NVARCHAR2(500)
)
CREATE TABLE Items
(
   ID RAW(16)  NOT NULL,
   Name NVARCHAR2(256)  NOT NULL,
   TemplateID RAW(16)  NOT NULL,
   MasterID RAW(16)  NOT NULL,
   ParentID RAW(16)  NOT NULL,
   Created TIMESTAMP(3) NOT NULL,
   Updated TIMESTAMP(3) NOT NULL,
   CONSTRAINT itemsid_ukey UNIQUE(ID)
)
CREATE TABLE ClientData
(
   SESSIONKEY NVARCHAR2(50) NOT NULL,
   Data NCLOB  NOT NULL,
   ACCESSED TIMESTAMP(3)  NOT NULL,
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL
)
CREATE TABLE IDTable
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   Prefix VARCHAR2(255)  NOT NULL,
   Key VARCHAR2(255)  NOT NULL,
   ParentID RAW(16) NOT NULL,
   CustomData VARCHAR2(255) NOT NULL,
   CONSTRAINT PK_IDTable PRIMARY KEY(Prefix,Key)
)
CREATE TABLE Shadows
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   ProxyID RAW(16) NOT NULL,
   TargetID RAW(16) NOT NULL,
   ShadowID RAW(16) NOT NULL
);


--INDEXES
CREATE  INDEX ndxKey ON ClientData
(SESSIONKEY ASC);

CREATE UNIQUE  INDEX ndxIDFld ON Fields
(ID ASC);

CREATE  INDEX ndxVersionID ON Fields
(VersionID ASC);

CREATE  INDEX ndxName ON Items
(Name ASC);

CREATE  INDEX ndxParentID ON Items
(ParentID ASC);

CREATE  INDEX ndxSourceItemID ON Links
(SOURCEITEMID ASC);

CREATE  INDEX ndxTargetItemID ON Links
(TARGETITEMID ASC);

CREATE  INDEX ndxKeyProp ON Properties
(Key ASC);

CREATE  INDEX ndxDate ON PublishQueue
("Date" ASC);

CREATE  INDEX ndxItemID ON Versions
(ItemID ASC);

CREATE  INDEX ndxItemIDWkfl ON WorkflowHistory
(ItemID ASC);

--SEQUENCE
CREATE SEQUENCE INDEX_SEQ INCREMENT BY 1 START WITH 
    21 MAXVALUE 1.0E28 MINVALUE 1 NOCYCLE 
    CACHE 20 NOORDER;

--FOREIGN KEY
ALTER TABLE Fields ADD  CONSTRAINT FK_VERSION FOREIGN KEY(VersionID)
REFERENCES Versions(ID) ON DELETE CASCADE;

ALTER TABLE Versions ADD CONSTRAINT FK_ITEM FOREIGN KEY(ItemID)
REFERENCES Items(ID) ON DELETE CASCADE
/

--- ********************************************
--- Creating schema for scExtranet
--- ********************************************

conn scExtranet/scExtranet@SITECORE

CREATE SCHEMA AUTHORIZATION scExtranet
CREATE TABLE PublishQueue
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   ItemID RAW(16)  NOT NULL,
   Language NVARCHAR2(50) DEFAULT 'en' NOT NULL,
   Version NUMBER(10,0) DEFAULT 1 NOT NULL,
   Action NVARCHAR2(50) DEFAULT ' '  NOT NULL,
   "Date" TIMESTAMP(3)  NOT NULL,
   "Index" NUMBER(10,0) NOT NULL
)
CREATE TABLE Fields
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   FieldID RAW(16)  NOT NULL,
   Value NCLOB,
   Created TIMESTAMP(3)  NOT NULL,
   Updated TIMESTAMP(3)  NOT NULL,
   VersionID RAW(16)  NOT NULL
)
CREATE TABLE Versions
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   Name NVARCHAR2(250),
   ItemID RAW(16) NOT NULL,
   Language NVARCHAR2(20) NOT NULL,
   Version NUMBER(10,0) NOT NULL,
   Created TIMESTAMP(3) NOT NULL,
   Updated TIMESTAMP(3) DEFAULT SYSTIMESTAMP NOT NULL,
   CONSTRAINT verid_ukey UNIQUE(ID)
)
CREATE TABLE WorkflowHistory
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   ItemID RAW(16)  NOT NULL,
   Language NVARCHAR2(20) NOT NULL,
   Version NUMBER(10,0) NOT NULL,
   OldState NVARCHAR2(200),
   NewState NVARCHAR2(200) NOT NULL,
   Text NVARCHAR2(2000),
   "User" NVARCHAR2(100) NOT NULL,
   "Date" TIMESTAMP(3) NOT NULL,
   SEQUENCE NUMBER(10,0) NOT NULL
)
CREATE TABLE Tasks
(
   ID RAW(16)  NOT NULL,
   NextRun TIMESTAMP(3)  NOT NULL,
   taskType NVARCHAR2(500)  NOT NULL,
   Parameters NCLOB,
   RECURRENCE NVARCHAR2(200)  NOT NULL,
   ItemID RAW(16)  NOT NULL,
   Database NVARCHAR2(50)  NOT NULL,
   Pending NUMBER(10,0)  NOT NULL,
   Disabled NUMBER(10,0)  NOT NULL
)
CREATE TABLE Properties
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   Key NVARCHAR2(256)  NOT NULL,
   Value NCLOB
)
CREATE TABLE Links
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   SOURCEDATABASE NVARCHAR2(50)  NOT NULL,
   SOURCEITEMID RAW(16)  NOT NULL,
   SOURCEFIELDID RAW(16)  NOT NULL,
   TARGETDATABASE NVARCHAR2(50)  NOT NULL,
   TARGETITEMID RAW(16)  NOT NULL,
   TARGETPATH NVARCHAR2(500)
)
CREATE TABLE Items
(
   ID RAW(16)  NOT NULL,
   Name NVARCHAR2(256)  NOT NULL,
   TemplateID RAW(16)  NOT NULL,
   MasterID RAW(16)  NOT NULL,
   ParentID RAW(16)  NOT NULL,
   Created TIMESTAMP(3) NOT NULL,
   Updated TIMESTAMP(3) NOT NULL,
   CONSTRAINT itemsid_ukey UNIQUE(ID)
)
CREATE TABLE ClientData
(
   SESSIONKEY NVARCHAR2(50) NOT NULL,
   Data NCLOB  NOT NULL,
   ACCESSED TIMESTAMP(3)  NOT NULL,
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL
)
CREATE TABLE IDTable
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   Prefix VARCHAR2(255)  NOT NULL,
   Key VARCHAR2(255)  NOT NULL,
   ParentID RAW(16) NOT NULL,
   CustomData VARCHAR2(255) NOT NULL,
   CONSTRAINT PK_IDTable PRIMARY KEY(Prefix,Key)
)
CREATE TABLE Shadows
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   ProxyID RAW(16) NOT NULL,
   TargetID RAW(16) NOT NULL,
   ShadowID RAW(16) NOT NULL
);


--INDEXES
CREATE  INDEX ndxKey ON ClientData
(SESSIONKEY ASC);

CREATE UNIQUE  INDEX ndxIDFld ON Fields
(ID ASC);

CREATE  INDEX ndxVersionID ON Fields
(VersionID ASC);

CREATE  INDEX ndxName ON Items
(Name ASC);

CREATE  INDEX ndxParentID ON Items
(ParentID ASC);

CREATE  INDEX ndxSourceItemID ON Links
(SOURCEITEMID ASC);

CREATE  INDEX ndxTargetItemID ON Links
(TARGETITEMID ASC);

CREATE  INDEX ndxKeyProp ON Properties
(Key ASC);

CREATE  INDEX ndxDate ON PublishQueue
("Date" ASC);

CREATE  INDEX ndxItemID ON Versions
(ItemID ASC);

CREATE  INDEX ndxItemIDWkfl ON WorkflowHistory
(ItemID ASC);

--SEQUENCE
CREATE SEQUENCE INDEX_SEQ INCREMENT BY 1 START WITH 
    21 MAXVALUE 1.0E28 MINVALUE 1 NOCYCLE 
    CACHE 20 NOORDER;

--FOREIGN KEY
ALTER TABLE Fields ADD  CONSTRAINT FK_VERSION FOREIGN KEY(VersionID)
REFERENCES Versions(ID) ON DELETE CASCADE;

ALTER TABLE Versions ADD CONSTRAINT FK_ITEM FOREIGN KEY(ItemID)
REFERENCES Items(ID) ON DELETE CASCADE
/

--- ********************************************
--- Creating schema for scSecurity
--- ********************************************

conn scSecurity/scSecurity@SITECORE

CREATE SCHEMA AUTHORIZATION scSecurity
CREATE TABLE PublishQueue
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   ItemID RAW(16)  NOT NULL,
   Language NVARCHAR2(50) DEFAULT 'en' NOT NULL,
   Version NUMBER(10,0) DEFAULT 1 NOT NULL,
   Action NVARCHAR2(50) DEFAULT ' '  NOT NULL,
   "Date" TIMESTAMP(3)  NOT NULL,
   "Index" NUMBER(10,0) NOT NULL
)
CREATE TABLE Fields
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   FieldID RAW(16)  NOT NULL,
   Value NCLOB,
   Created TIMESTAMP(3)  NOT NULL,
   Updated TIMESTAMP(3)  NOT NULL,
   VersionID RAW(16)  NOT NULL
)
CREATE TABLE Versions
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   Name NVARCHAR2(250),
   ItemID RAW(16) NOT NULL,
   Language NVARCHAR2(20) NOT NULL,
   Version NUMBER(10,0) NOT NULL,
   Created TIMESTAMP(3) NOT NULL,
   Updated TIMESTAMP(3) DEFAULT SYSTIMESTAMP NOT NULL,
   CONSTRAINT verid_ukey UNIQUE(ID)
)
CREATE TABLE WorkflowHistory
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   ItemID RAW(16)  NOT NULL,
   Language NVARCHAR2(20) NOT NULL,
   Version NUMBER(10,0) NOT NULL,
   OldState NVARCHAR2(200),
   NewState NVARCHAR2(200) NOT NULL,
   Text NVARCHAR2(2000),
   "User" NVARCHAR2(100) NOT NULL,
   "Date" TIMESTAMP(3) NOT NULL,
   SEQUENCE NUMBER(10,0) NOT NULL
)
CREATE TABLE Tasks
(
   ID RAW(16)  NOT NULL,
   NextRun TIMESTAMP(3)  NOT NULL,
   taskType NVARCHAR2(500)  NOT NULL,
   Parameters NCLOB,
   RECURRENCE NVARCHAR2(200)  NOT NULL,
   ItemID RAW(16)  NOT NULL,
   Database NVARCHAR2(50)  NOT NULL,
   Pending NUMBER(10,0)  NOT NULL,
   Disabled NUMBER(10,0)  NOT NULL
)
CREATE TABLE Properties
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   Key NVARCHAR2(256)  NOT NULL,
   Value NCLOB
)
CREATE TABLE Links
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   SOURCEDATABASE NVARCHAR2(50)  NOT NULL,
   SOURCEITEMID RAW(16)  NOT NULL,
   SOURCEFIELDID RAW(16)  NOT NULL,
   TARGETDATABASE NVARCHAR2(50)  NOT NULL,
   TARGETITEMID RAW(16)  NOT NULL,
   TARGETPATH NVARCHAR2(500)
)
CREATE TABLE Items
(
   ID RAW(16)  NOT NULL,
   Name NVARCHAR2(256)  NOT NULL,
   TemplateID RAW(16)  NOT NULL,
   MasterID RAW(16)  NOT NULL,
   ParentID RAW(16)  NOT NULL,
   Created TIMESTAMP(3) NOT NULL,
   Updated TIMESTAMP(3) NOT NULL,
   CONSTRAINT itemsid_ukey UNIQUE(ID)
)
CREATE TABLE ClientData
(
   SESSIONKEY NVARCHAR2(50) NOT NULL,
   Data NCLOB  NOT NULL,
   ACCESSED TIMESTAMP(3)  NOT NULL,
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL
)
CREATE TABLE IDTable
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   Prefix VARCHAR2(255)  NOT NULL,
   Key VARCHAR2(255)  NOT NULL,
   ParentID RAW(16) NOT NULL,
   CustomData VARCHAR2(255) NOT NULL,
   CONSTRAINT PK_IDTable PRIMARY KEY(Prefix,Key)
)
CREATE TABLE Shadows
(
   ID RAW(16) DEFAULT SYS_GUID() NOT NULL,
   ProxyID RAW(16) NOT NULL,
   TargetID RAW(16) NOT NULL,
   ShadowID RAW(16) NOT NULL
);


--INDEXES
CREATE  INDEX ndxKey ON ClientData
(SESSIONKEY ASC);

CREATE UNIQUE  INDEX ndxIDFld ON Fields
(ID ASC);

CREATE  INDEX ndxVersionID ON Fields
(VersionID ASC);

CREATE  INDEX ndxName ON Items
(Name ASC);

CREATE  INDEX ndxParentID ON Items
(ParentID ASC);

CREATE  INDEX ndxSourceItemID ON Links
(SOURCEITEMID ASC);

CREATE  INDEX ndxTargetItemID ON Links
(TARGETITEMID ASC);

CREATE  INDEX ndxKeyProp ON Properties
(Key ASC);

CREATE  INDEX ndxDate ON PublishQueue
("Date" ASC);

CREATE  INDEX ndxItemID ON Versions
(ItemID ASC);

CREATE  INDEX ndxItemIDWkfl ON WorkflowHistory
(ItemID ASC);

--SEQUENCE
CREATE SEQUENCE INDEX_SEQ INCREMENT BY 1 START WITH 
    21 MAXVALUE 1.0E28 MINVALUE 1 NOCYCLE 
    CACHE 20 NOORDER;

--FOREIGN KEY
ALTER TABLE Fields ADD  CONSTRAINT FK_VERSION FOREIGN KEY(VersionID)
REFERENCES Versions(ID) ON DELETE CASCADE;

ALTER TABLE Versions ADD CONSTRAINT FK_ITEM FOREIGN KEY(ItemID)
REFERENCES Items(ID) ON DELETE CASCADE
/

exit